import AccessControl
import OFS, Globals
import types
from TraversableWrapper import Traversable
from Globals import Persistent
from AccessControl import ClassSecurityInfo
from Cruft import Cruft
from common import add_dtml

class ValikYlesanne(Persistent):
    "Valikvastustega lesanne"
    meta_type='ValikYlesanne'
    security=ClassSecurityInfo()
    security.declareObjectPublic()
 
    def __init__(self, uuskysimus, uusvastus=1):
        """
        """
        self.kysimus=uuskysimus
        if self.sobivuskontroll(uusvastus):
          self.vastus=uusvastus # kas 0 vi 1
        else:
          raise Exception("sobimatu vastus")
          
    def sobivuskontroll(self, valik):
       if valik==0 or valik==1:
          return 1
       else:
          return 0
        
    def annaKysimus(self):
        return self.kysimus
        



class ValikTest(
     OFS.Folder.Folder,
     Persistent,
     AccessControl.Role.RoleManager,
     Traversable,
     Cruft
     ):
    "jah/ei test"
    meta_type='ValikTest'
    dtml_files=(
      ('muuda_vorm', 'muuda', 'ui/Valik/muuda_vorm'),
      ('taida_vorm', 'taida', 'ui/Valik/taida_vorm'),
      ('kysimuse_vorm', 'kysimusvorm', 'ui/Valik/kysimuse_vorm'),
    )
    security=ClassSecurityInfo()
    security.declareObjectPublic()
    
    def __init__(self, nimi='Valiktest'):
       "Uus test"
       self._nimi=nimi
       self._ylesanded=[]
       for tup in self.dtml_files:
            add_dtml(self, tup)
      
    def lisaYlesanne(self, kysimus, vastus):
       "uus lesanne testis"
       self._ylesanded.append(ValikYlesanne(kysimus, vastus))
       self._ylesanded=self._ylesanded #et muutus siliks
       
    def kysimused(self):
       "Ksimuste loetelu"
       k=[]
       for x in self._ylesanded:
         k.append(x.kysimus)
       return k
       
    def ylesanded(self):
       "lesannete loetelu"
       return self._ylesanded 
     
    def nimi(self):
       "Testi nimi"
       return self._nimi    
       
    def ylesanne(self, nr):
       "vastava jrjekorranumbriga lesanne"
       return self._ylesanded[nr].kysimus
       
    def vastus(self, nr):
       "vastava jrjekorranumbriga vastus"
       return self._ylesanded[nr].vastus
       
    def ylesanneteArv(self):
       "lesannete arv"
       return len(self._ylesanded)
       
    def tutvustus(self):
       "Testi tutvutus"
       return "Jah/ei test"
       
    def kysimuse_lisamise_leht(self, REQUEST, kysimus, vastus='ei'):
       "Sisestatud ksimus ptakse kinni"
       if(vastus=='jah'):  
         v=1
       else:
         v=0
       self.lisaYlesanne(kysimus, v)
       REQUEST.RESPONSE.redirect('muuda_vorm')
       
    def muuda_vorm_py(self):
       "muutmisvorm"
       tulemus="""
         <form action="kustuta_leht">
       """
       if len(self._ylesanded)>0:
         tulemus=tulemus+"""
           <table>
             <tr>
               <td>Ksimus</td>
               <td>Valik</td>
               <td>Muuda</td>
               <td>Kustuta</td>
             </tr>
         """
         for x in range(0,len(self._ylesanded)):
          k=self._ylesanded[x].kysimus
          t="-"
          if self._ylesanded[x].vastus:
           t="+"
          tulemus=tulemus+"""
            <tr>
              <td>%s</td>
              <td align="center">%s</td>
              <td><a href="kysimuse_vorm?muuda=%d&kysimus=%s&vastus=%s">muuda</a></td>
              <td align="center"><input type="checkbox" name="kustuta" value="%d"></td>
            </tr>""" % (k, t, x, self.urlquote(k), self.urlquote(str(self._ylesanded[x].vastus)), x)
         tulemus=tulemus+"""</table> <br/><input type="submit" value="Kustuta valitud" /> """
       tulemus=tulemus+"""<a href="kysimuse_vorm">Lisa ksimus</a>
               </form>
               """
       return tulemus
       
    def taida_vorm_py(self):
       "Titmisvorm"
       tulemus="""
         <form action="loeAndmedLehelt">
           <ul>
       """
       for x in range(0,len(self._ylesanded)):
         tulemus=tulemus+"""
            <li><input type="checkbox" name="pakutud" value="%d">
            %s</li>""" % (x, self._ylesanded[x].kysimus)
       tulemus=tulemus+"""
               </ul>
               <input type="submit" value="Salvesta" />
               </form>
               """
       return tulemus
       
    def kustuta_leht(self, REQUEST, kustuta=None):
        "kustutatakse mrgitud read"
        if kustuta is not None:
          import types
          if type(kustuta) is types.StringType:
            kustuta=(kustuta,)
          alles=[]
          for nr in range(len(self._ylesanded)):
            if str(nr) not in kustuta:
               alles.append(self._ylesanded[nr])
          self._ylesanded=alles
          #return "valmis"
        REQUEST.RESPONSE.redirect('muuda_vorm')

    def loeAndmedLehelt(self, REQUEST, pakutud=None):
        "Veebilt tulevad andmed talde"
        #return "kukuk"+str(self.get_id())+self.id
        if pakutud is None:
           pakutud=()
        if type(pakutud) is types.StringType:
           pakutud=(pakutud,)
        vtv=ValikTestiVastus()
        vtv.loeAndmed(self, pakutud)
        vtv.testiID=self.get_id()
        self.parent().paigutaTestiVastus(REQUEST, vtv)
        return "andmed paigas"


           
       

class ValikYlesandeVastus(ValikYlesanne):
    "Valikvastustega lesande vastus"
    meta_type='ValikYlesandeVastus'
    security=ClassSecurityInfo()
    security.declareObjectPublic()

    def __init__(self, uuskysimus, uusvastus, uuspakutu):
       ""
       ValikYlesanne.__init__(self, uuskysimus, uusvastus)
       if self.sobivuskontroll(uuspakutu):
         self.pakutu=uuspakutu
       else:
         raise Exception("sobimatu pakutu")
          
    def annaPakutu(self):
        if hasattr(self, pakutu):
           return self.pakutu
        else:
           return -1
 
    def kasPihtas(self):
        return self.pakutu==self.vastus

class ValikTestiVastus(
     OFS.Folder.Folder,
     Persistent,
     AccessControl.Role.RoleManager):
     "jah/ei testi vastused"
     meta_type='ValikTestiVastus'
    
     
     def loeAndmed(self, test, pakutud):
        "Andmed koos pakututega talde"
        self.vastused=[]
        yl=test.ylesanded()
        for nr in range(len(yl)):
          sees=0
          if str(nr) in pakutud:
            sees=1
          self.vastused.append(ValikYlesandeVastus(yl[nr].kysimus, yl[nr].vastus, sees))
        self.vastused=self.vastused
          
     def kokkuPihtas(self):
        "Tabamuste arv"
        kokku=0
        for x in self.vastused:
           if x.kasPihtas():
              kokku=kokku+1
        return kokku
        
     def pihtasProtsent(self):
        return self.kokkuPihtas()*100/len(vastused)
        

     def index_html(self):
        "avaleht"
        return self.tulemusteTabel()

     def tulemusteTabel(self):
        "Vastuste tabel"
        tulemus="""
          <table>
            <tr>
              <td>Ksimus</td>
              <td>ige vastus</td>
              <td>Pakutud</td>
              <td>Kas pihtas</td>
            </tr>
        """
        for x in self.vastused:
          vastus="-"
          pakutu="-"
          korras="-"
          if x.vastus: vastus="+"
          if x.kasPihtas(): korras="+"
          if x.pakutu: pakutu="+"
          tulemus=tulemus+("\n<tr><td>%s</td><td>%s</td><td>%s</td><td>%s</td></tr>"%
              (x.kysimus, vastus, pakutu, korras))
        tulemus=tulemus+"</table>"      
        return tulemus      
          
           
Globals.default__class_init__(ValikTest)
