# $Id: vocabulary.py,v 1.6 2003/08/18 07:44:24 berlingo Exp $
#
# Copyright 2003 by IVA Team and contributors
#
# This file is part of IVA.
#
# IVA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# IVA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with IVA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Contains the english translations for all IVA printable strings."""

# How to do a new translation:
#
# 1. Copy this file into a new file, appending the language code after it, so
# you get something like "vocabulary_es.py" for Spanish and so on.
#
# 2. Edit the new file, translating the second portion of each line. The
# first portion is the keyword, which you shouldn't touch. The second is the
# translation that should be translated to the target language. The third
# is the supplementary instruction, that should help you do the translations.
#
# 3. Please note that the file is in Python code and needs to follow certain
# syntax rules:
#  - Strings can either be quoted by singles quotes (') or double quotes (").
#    If you need to use either of these quotation marks in your translation,
#    make sure that you use the other quotation mark to surround the string.
#    If you need to use both quotation marks in the same translation string,
#    you can surround the string with triple quotes (''' or """), which
#    allows you to use either of the quotation marks inside the string.
#  - Line breaks are not allowed inside strings, so make sure you don't
#    use an editor that wraps lines. You can have line breaks between
#    strings, though.
#
# 4. If you need to use special characters (outside of the 127 character
# ASCII range), you have several choices:
#
# A. Write in your native encoding (whatever suits you best). This requires
#    that you change the "charset_encoding" keyword in the "common" module to
#    the encoding type you will use. This document is written in iso8859-1,
#    although as english does not contain special characters, it could be
#    in utf-8 as well without any differences.
#    Most European languages are easiest to write in iso8859-1.
#
# B. Write in utf-8 encoded unicode. If your editor can save files in utf-8,
#    use that feature. If not, you can add the special characters manually
#    with the \x escape sequences. Make sure you remove the keyword
#    "charset_encoding" from the "common" module, or change its value to
#    "utf-8" so that the strings are interpreted correctly.
#    'key': ('\xe3\x82\xaa','This is the katakana letter O,encoded in utf-8.'),
#
# C. Write in unicode. Each unicode string starts with u followed by the
#    quotes. Each unicode character starts with \u followed by the code in
#    hexadecimal notation. The value of the "charset_encoding" keyword
#    is irrelevant if you use unicode all the way.
#    'key': (u'\u30aa','This is the katakana letter O, encoded in unicode.'),
#
# 5. Check your translation. If you have Python installed and you've
#    downloaded IVA sources, you can execute "python TranslationLint.py"
#    which will check through all the translation files and will produce
#    an error if there is a syntax error.
#    If you have installed IVA, you can test the translation yourself
#    by going to Zope Management and selecting the Tools tab in your IVA
#    instance, and clicking on "reload_translations". After this you
#    should be able to select your translation from user preferences
#    and see the translated strings.
#

common = {
    'language_name': ('English', 'Name of this language'),
    'charset_encoding': ('iso8859-1','Encoding used in this translation (if missing, utf-8 is assumed'),
    'WebTop': ('WebTop','Main tab for webtop'),
    'Knowledge_Building': ('Knowledge Building','Main tab for knowledge building'),
    'Course_Management': ('Course Management','Main tab for course management'),
    'User_Management': ('Participants','Main tab for user management'),
    'Jamming': ('Jamming', 'Main tab for jamming'),
    'Type_Management': ('Knowledge Type Management','Heading'),
    'cancel': ('Cancel','Button label'),
    'submit': ('Submit','Button label'),
    'remove': ('Remove','Button label'),
    'next': ('Next ->','Label for button'),
    'previous': ('<- Previous','Label for button'),
    'quick_submit': ('Quick submit',''),
    'ok': ('Ok','Button label'),
    'webtop': ('Webtop',''),
    'bookshelf': ('Bookshelf',''),
    'description': ('Description','Label'),
    'short_date_format_display': ('YYYY-MM-DD', 'String displayed as clue when entering a date'),
    'short_date_format': ('%Y-%m-%d', 'Format string for short dates'),
    'timestamp_format': ('%H:%M %Y-%m-%d', 'Format string for long timestamps'),
    'invite': ('Invite',''),
    'add': ('Add',''),
    'today': ('Today',''),
    'yesterday': ('Yesterday',''),
    'groupfolder': ('course folder','Heading'),
# v1.9:
    'dtml_reloaded': ('DTML reloaded','Title for message dialog'),
    'dtml_files_reloaded': ('DTML files reloaded for this object','Message dialog text'),
    'dtmls_reloaded': ('DTMLs reloaded','Title for message dialog'),
    'dtmls_files_reloaded': ('All DTML files reloaded','Message dialog text'),
    'css_reloaded': ('Style sheets reloaded','Title for message dialog'),
    'css_files_reloaded': ('Style sheet files reloaded for this object','Message text'),
    'error': ('Error',''),
    'warning': ('Warning',''),
# v1.26:
    'invalid_url': ('Invalid url', 'Message title'),
    'give_valid_url': ('Please enter a valid URL', 'Message text'),
    'invalid_name': ('Invalid name','Message title'),
    'give_valid_name': ('Please enter a valid name','Message text'),
    'name_taken': ('Another item already has the name "%s". Please enter another name.','Message text, name inserted inside'),
# v1.31:
    'edit': ('Edit','Button label'),
    'you_are_in': ('You are in:', 'Heading, without trailing colon - keep in translation if needed'),
    'required_field_missing': ("You didn't fill all the required fields.", 'Erro message text'),
    'confirmation': ('Confirmation', 'Title for confirmation dialogs'),
    'invalid_input': ('Invalid input', 'Message title'),
    'invalid_fields': ('The following fields have invalid input', 'Message text followed by a list of field names'),
    'select_item_first_common': ('Select some items first', 'Message text'),
    'link_to_webtop': ('Create link on WebTop','Link'),
    'proxy_to_webtop': ('Link course folder to WebTop','Link'),
    'export': ('Export','Button label'),
    'import': ('Import','Button label'),
    'importing': ('Importing','Heading start'),
    'megabyte': ('MB', 'Abbreviation for megabyte'),
    'kilobyte': ('kB', 'Abbreviation for kilobyte'),

    'logout': ('Logout', 'Link for logging out, also heading in logout dialogs'),
    'logout_pre': ("To log out, either close your browser or press the <b>Logout</b> button below. When your browser asks for a username and password, just press <b>Cancel</b>. This will clear your login information from your browser's cache",'Instructions on logging out'),
    'logout_post': ("You have been logged out.",'Logout notification'),
    'login': ('Login','Link to log in')
    }

kb = {
    'course_info': ('Course information', 'Label for link to course details'),
    'create_context': ('Create course context', 'Link to create new course context'),
    'hide_context': ('Hide context', 'Link to hide a context from view'),
    'show_context': ('Show context', 'Link to show a hidden context'),
    'new_notes': ('new notes', 'Label for showing the number of new notes, eg. "5 new notes"'),
    'notes_total': ('notes', 'Label for showing the number of notes'),
    'full_description': ('full description...', ''),
    'course': ('course',"String 'course' in context display"),
    'context': ('context',"String 'context' in context display"),
    'thread': ('thread',"String 'thread' in context display"),
    'note': ('note',"String 'note' in context display"),
    'start_new_thread': ('Start a new thread','Link'),
    'short_description': ('Short description','Label'),
    'long_description': ('Long description','Label'),
    'full_description': ('Full description','Label'),
    'select': ('Select','Start of sentence, followed by a drop-down list of available knowledge types'),
    'knowledge_type': ('knowledge type','Label'),
    'reply': ('Reply','Button label'),
    'show_notes': ('Show notes','Heading start'),
    'show_thread': ('as thread','heading finish'),
    'show_type': ('by knowledge type','heading finish'),
    'show_author': ('by person','heading finish'),
    'show_date': ('by date','heading finish'),
    'change_course_to': ('Change to another course','Label, followed by a drop-down list of available courses'),
    'creating_context': ('Creating new course context in','Title, followed by the course name'),
    'editing_context': ('Editing course context in','Title, followed by the course name'),
    'title_of_context': ('Title of the course context','Label'),
    'type_set': ('Knowledge type set','Label'),
    'creating_note_in': ('Creating new note in','Title, followed by course context name'),
    'course_context': ('course context','Label for course context'),
    'you_are_replying_to': ('You are replying to','Label'),
    'title_of_note': ('Title for the note','Label'),
    'message_body': ('Message body','Label'),
    'current_image': ('Current image','Label'),
    'replace_with': ('Replace with','Label for image replacement in note edit'),
    'add_image': ('Add image','Label'),
    'title_of_image': ('Title for the image','Label'),
    'add_link': ('Add link (URL)','Label'),
    'title_of_link': ('Title for the link','Label'),
    'preview': ('Preview','Button label'),
    'previewing_note': ('Previewing the note in','Title/heading, followed by course context name'),
    'publish': ('Publish','Button label'),
# v1.19:
    'you_didnt_select_type': ("You didn't select any knowledge type.",'Title'),
    'go_back': ('Go back','Start of message, rendered into a link'),
    'and_select_type': ('and select the knowledge type for your note.','Rest of message'),
    'inline_notes': ('Show bodies of all notes','Link'),
    'outline_notes': ('Hide bodies of all notes','Link'),
    'view_info': ('view information','Part of location bar'),
    'edit_context': ('Edit course context','Link'),
# v1.27:
    'to_note': ('to note','Part of a message'),
# v1.31:
    'full_thread_no': ('Show only starting notes', 'Link'),
    'full_thread_yes': ('Show full thread', 'Link'),
    'censor': ('Censor note','Button label for censoring notes'),
    'uncensor': ('Uncensor note','Button label for uncensoring notes'),
    'censored_msg': ('Message is censored','Message shown when teacher censores a note.'),
    'censor_verify': ('Are you sure you want to censor this message? Your name and this date will be stored and displayed along with the censorship notice to everyone viewing this note.','Verification message shown when censoring is attempted'),
    'censored_subject': ('Censored','Title/subject for censored notes'),
    'censored_body': ('This message has been censored by %s at %s.',"Body for censored messages. First placeholder is replaced by censorer's name and the second by the date"),
    'notes_from_day': ('Notes from','Start of heading, followed by a date'),
    'previous': ('Previous', 'Link label'),
    'next': ('Next', 'Link label'),
    'who_has_read': ('Who has read this note?', 'Link label'),
    'last_read': ('Last read', 'Label'),
    'times_read': ('Times read', 'Label'),
    'back': ('< back', 'Link label'),
    'unread_to_read_msg': ('All notes in a thread marked as read.', 'title and message in a message dialog'),
    'mark_notes_read': ('Mark all notes as read', 'text in a button'),
    'creating_groupfolder': ('Creating a new course folder in','Heading start'),
    'title_groupfolder': ('Title of course folder','Label'),
# v1.87:
    'flea_asks': ('Flea asks','Heading displayed in the scaffolding check list. Flea is the name of the FLE-helper.'),
    'change_type': ('Change the Knowledge Type?', 'Question at the end of the scaffolding check list.'),
    'no_change_possible': ('This is the only type allowed here.','Text displayed when there is only one possible follow-up type and the type cannot be changed.'),
    'change': ('Change', 'Button label'),
    'down_to_note': ('Down', 'Link label'),
    }

webtop = {
    'users_courses': ("Courses","Heading for user's course list"),
    'new_notes': ('new notes','Label for displaying the number of new notes in a course'),
    'total_notes': ('total','Label for displaying the total number of notes in a course'),
    'add_folder': ("Add folder",""),
    'add_document': ("Add document",""),
    'add_link': ("Add link",""),
    'create_document': ("Create memo",""),
    'sort': (' ','Common heading for sort links by_name and by_date'),
    'by_name': ('by name','Link for sorting by name'),
    'by_date': ('by date','Link for sorting by date'),
    'by_size': ('by size', 'Link for sorting by size'),
    'remove': ('Remove','Button label'),
    'restore': ('Restore','Button label'),
    'rename': ('Rename', 'Button label'),
    'copy': ('Copy','Button label'),
    'cut': ('Cut','Button label'),
    'paste': ('Paste','Button label'),
    'delete': ('Delete','Button label'),
    'trash': ('Trash','Label for trashcan'),
    'adding_folder': ('Adding a folder','Heading'),
    'title_of_folder': ('Title of the folder','Label'),
    'viewing_memo': ('Viewing a memo', 'Title'),
    'adding_memo': ('Adding a memo','Title'),
    'editing_memo': ('Editing a memo','Title'),
    'name_of_memo': ('Name of the memo','Label'),
    'content': ('Contents','Label'),
    'show_memo_contents': ('Show only memo contents','Link'),
    'adding_link': ('Adding a link','Title'),
    'title_of_link': ('Title of the link','Label'),
    'url': ('URL',''),
    'document_uploaded': ('Document uploaded.','Status message'),
    'adding_document': ('Adding a document', 'Title'),
    'upload_document': ('Upload document','Label'),
    'title_of_document': ('Title of the document','Label'),
# v1.9:
    'webtop_link_added': ('WebTop link added','Message title'),
    'added_webtop_link': ('A link %s "%s" was created on your Webtop. Click OK to return to the previous page.','Message text; "to type" and "name" inserted into placeholders (2)'),
    'proxy_added': ('Course folder added', 'Message title'),
    'added_proxy': ('The course folder of course %s is now visible on your Webtop. Click OK to return to the previous page.', 'Message text, course name inserted into placeholder'),
    'no_item_selected': ('No items selected!','Message dialog title'),
    'select_item_first': ('Please select at least one item to perform actions other than paste.','Message dialog message'),
    'no_file_supplied': ('No file supplied.','Message text'),
    'renaming': ('Renaming', 'Title'),
    'invalid_names': ('The following names are invalid:', 'Message dialog messsage'),
    'same_names': ('You gave the same name for several objects.', 'Message dialog message'),
    'names_in_use': ('The following names are already in use:', 'Message dialog message'),
# v1.19:
    'information': ('User information','Link'),
    'preferences': ('Preferences','Link'),
    'editing_preferences': ('Editing preferences','Title'),
    'shared': ('Shared', 'Printed after the name of the group folder'),
    }

coursemgmnt = {
    'course': ('course', 'part of browser title'),
    'courses': ('Courses','Title'),
    'add_course': ('Add course','Link'),
    'edit_course': ('Edit course','Button label'),
    'edit_participants': ('Edit participants','Button label'),
    'creating_course': ('Creating new course','Title'),
    'editing_course': ('Editing course','Title'),
    'course_name': ('Course name','Label'),
    'organization': ('Organization','Label'),
    'methods': ('Methods','Label'),
    'starting_date': ('Starting date','Label'),
    'ending_date': ('Ending date','Label'),
    'create_groupfolder': ('Create group folder','Link'),
    'adding_users_to_course': ('Adding new users to course','Title, name of course is displayed after this'),
    'if_participants_not_users': ('In case the course participants are not yet IVA users','Message'),
    'new_participants_to_system': ('new participants to IVA system', 'Part of a phrase'),
    'by_email': ('by e-mail','Part of a phrase'),
    'manually': ('manually','Part of a phrase'),
    'fle_users': ('IVA Users','Heading'),
    'down': ('Down','Button label'),
    'up': ('Up','Button label'),
    'teachers': ('Teachers','Heading'),
    'tutors': ('Tutors','Heading'),
    'students': ('Students','Heading'),
    'add_button': ('Add ->','Button label'),
    'remove_button': ('<- Remove','Button label'),
# v1.9:
    'no_course_selected': ('No course selected!','Message dialog title'),
    'select_course_first': ('Please select a course from the course list.','Message dialog message'),
    'set_published': ('Knowledge type set published','Message dialog title/text'),
    'users_updated': ('Users updated','Message dialog title/message'),
    'select_some_users': ('Please select some users','Message dialog title/message'),
# v1.19:
    'edit_course_info': ('Edit course information','Link'),
    'edit_course_participants': ('Edit course participants','Link'),
    'date': ('Date','Label, followed by the starting and ending date of the course.'),
    'course_participants': ('Course participants','Label'),
    'type_sets': ('Knowledge type sets','Label, plural'),
    'delete': ('Delete','Button label'),
# v1.31:
    'new_typeset': ('Add new knowledge type set','Link'),
    'tt_yellow': ('Yellow','Knowledge type colour name'),
    'tt_yellowlt': ('Light yellow','Knowledge type colour name'),
    'tt_orange': ('Orange','Knowledge type colour name'),
    'tt_orangelt': ('Light orange','Knowledge type colour name'),
    'tt_red': ('Red','Knowledge type colour name'),
    'tt_pink': ('Pink','Knowledge type colour name'),
    'tt_purple': ('Purple','Knowledge type colour name'),
    'tt_blue': ('Blue','Knowledge type colour name'),
    'tt_bluelt': ('Light blue','Knowledge type colour name'),
    'tt_aqua': ('Aqua','Knowledge type colour name'),
    'tt_green': ('Green','Knowledge type colour name'),
    'tt_greenlt': ('Light green','Knowledge type colour name'),
    'tt_gray': ('Gray','Knowledge type colour name'),
    'tt_white': ('White','Knowledge type colour name'),
    'edit_typeset': ('Editing Knowledge type set','Heading'),
    'create_typeset': ('Creating new Knowledge type set','Heading'),
    'form': ('Form','Start of heading'),
    'name': ('Title','Start of label'),
    'of_typeset': ('of the knowledge type set','Ending of label'),
    'abbreviations_and_icons': ('abbreviations and icons','Ending for heading'),
    'type': ('Knowledge type','Label'),
    'types': ('Knowledge types','Title'),
    'abbreviation': ('Abbreviation','Label'),
    'color': ('Colour','Label'),
    'icon': ('Icon','Label'),
    'starting_phrase': ('Starting phrase','Label'),
    'checklist': ('Check list','Label'),
    'no_types_entered': ("You haven't entered any knowledge types. A set must include at least one type.",'Error message for when a new set is created with no types'),
    'restrictions_of_use': ('Restrictions of use','Heading sentence.'),
    'that_can_start_thread': ('that can start a discussion','End of label'),
    'viewing_type': ('viewing knowledge type','Part of location bar'),
    'new_typeset_from': ('Duplicate and edit knowledge type set','Link, followed by knowledge type set name'),
    'unfinished': ('Unfinished','Label'),
    'manage_types': ('Manage knowledge types','Link'),
    'finalize_typeset': ('Change status to Finished','Button label'),
    'are_you_sure': ('Are you sure you want to delete the following courses:' , 'Message dialog message'),
    'are_you_sure_ctx': ('Are you sure you want to delete this course context:' , 'Message dialog message'),
    'are_you_sure_tts': ('Are you sure you want to delete the following knowledge type sets:' , 'Message dialog message'),
    'typeset_importing': ('Please select the zipped export file containing the knowledge type sets you wish to import.','Instructions for typeset importing'),
    'typesets_imported': ('New knowledge type sets have been imported.','Message'),
    'import_typeset': ('Import knowledge type set','link'),
    'course_importing': ('Please select the zipped export file containing the courses you wish to import.','Instructions for course importing'),
    'courses_imported': ('New courses have been imported.','Message'),
    'import_course': ('Import courses','link'),

 #Sorting the users under user management #06.08 by Mart
  'sort_by':('Sort by','Text before pull-down menu'),
  'limiters':('Limit by','Text before pull-down menu'),
  'modified':('Creating date','menu option'),
  'username':('Username','menu option'),
  'sort':('Sort','button label'),
  'not_specified':('Not specified','default menu option'),
  'email':('e-mail','menu option'),
  'fname':('first name','menu option'),  
  'since':('since','default value of textbox'),
  'until':('until','default value of textbox'), 
    }

usermgmnt = {
    'user': ('user', 'part of browser title'),
    'adding_users': ('Adding new users', 'Title'),
    'required_field': ('Required field',''),
    'nickname': ('Nickname','Label'),
    'user_account': ('User account','Label'),
    'Confirm': ('Confirm',''),
    'you_are_removing': ('You are removing',''),
    'invite_user': ('Invite user',''),
    'invite_new_users': ('Invite new users','Heading for invitation form'),
    'email_addresses': ('E-mail addresses',''),
    'separate_with_comma': ('( separate with: , )',''),
    'Invitation_message': ('Invitation message',''),
    'Invitation_language': ('Invitation language', ''),
    'Courses_to_invite_to': ('Courses to invite to', ''),
    'Freeze': ('Freeze',''),
    'Remove': ('Remove',''),

    'role': ('Role', 'label'),
    'role_staff': ('Staff', 'Global role stuff'),
    'role_user': ('User', 'Global role user'),
    'role_fleadmin': ('IVA Admin', 'Global role ivaadmin'),

    'invite_again': ('Invite again','Button label'),
    'warning': ('Warning','Heading'),
    'want_remove_users': ('Do you want to remove the following users?','Complete question'),
    'invited_user_manage': ('Management of invited users','Title'),

    'info_user': ('Information about ','Title for user info page, prefix before usre name'),
    'edit_user': ('Edit user','Link'),
    'name': ('User name',''),
    'editing': ('Editing','Heading for user edit, inserted before user name'),
    'image_of_user': ('Image of the user','Label'),
    'upload_image_of_user': ('Upload your image','Label'),
    'or_link_to_image': ('or give a link to an image','Label, continuing from the upload label'),
    'add_new_user': ('Adding new user','Title'),
    'webtop_bg': ('Select a WebTop background image', 'Label'),
    'upload_webtop_bg': ('or upload your own background image', 'Label, continuing from the webtop_bg'),
    'show_pending_users': ('Check invites',''),
    'add_user': ('Add user',''),
    'Unfreeze': ('Unfreeze',''),
    'Users': ('Users',''),
    'gsm': ('Mobile',''),
    'last_name': ('Last name',''),
    'first_name': ('First name',''),
    'city': ('City',''),
    'organization': ('Organization',''),
    'professional_interests': ('Professional interests',''),
    'email': ('Email',''),
    'phone': ('Phone',''),
    'language': ('Language',''),
    'url_to_photo': ('URL to picture',''),
    'country_menu_default': ('Select country',''),
    'group_menu_default': ('Select group','Default value for drop-down menu'),
    'address': ('Address',''),
    'address1': ('Address line 1',''),
    'address2': ('Address line 2',''),
    'personal_interests': ('Personal interests',''),
    'quote': ('Quote',''),
    'homepage': ('Homepage',''),
    'upload': ('Upload',''),
    'group': ('Group',''),
    'password': ('Password',''),
    'background': ('Background',''),
    'country': ('Country',''),
# v1.9:
    'reserved_nickname': ('Sorry. That nickname is already taken.', 'Message'),
    'password_mismatch': ("Supplied passwords don't match.",'Message'),
    'could_not_send_invitation': ('Could not send invitation message. Please check that your MailHost object is configured properly.','Error message'),
    'invitations_sent': ('Invitations sent','Message title'),
    'invitations_sent_to': ('Invitations sent to %s. ','Message, email list is inserted into the placeholder.'),
    'users_removed': ('Users removed','Message title'),
    'removed_users': ('Users removed: %s','Message, list inserted inside'),
    'not_removed_users': ('Unable to remove these users: %s','Message, list inserted inside'),
    're_invitations_sent': ('Re-invitations sent','Message title'),
    're_invitations_sent_to': ('Re-invitations sent to %s users. ','Message, email count is inserted into the placeholder.'),
    'pending_users_removed': ('Pending users removed','Message title'),
    'pending_removed_users': ('Pending users removed: %s','Message, list inserted inside'),
    'pending_not_removed_users': ('Unable to remove these pending users: %s','Message, list inserted inside'),
    'invitation_subject': ('Invitation to IVA','Subject for invitation messages'),
    'invitation_header': ('Invitation','Header for invitation messages'),
    'invitation_footer': ('Please visit: ','Footer for invitation messages; followed by the URL'),
# v1.15:
    'welcome_message': ('Welcome to IVA. Please fill in your user information below.','Welcome message used in invitation registration form'),
    'uname': ('User name','Label used in invitation registration form'),
    'registration_failed': ('Registration failed',"Title used when invited user can't register."),
    'invitation_key_used': ("This invitation URL has already been used or is no longer valid. If you have not been able to register, please contact your teacher to get another invitation.",'Message telling that the registration url has been used.'),
    'authorization_failed': ('Authentication keys are invalid',"Message telling that the authentication key isn't valid."),
# v1.19:
    'after_submit_give_name_and_passwd': ('After hitting "Submit" give your user name and password.','Message'),
# v1.21:
    'frozen': ('Frozen','User status code'),
# v1.22:
    'no_email': ('No email address', 'Message title'),
    'no_email_explanation': ("You can't send email because you haven't set your email address.", 'Message text'),
    'passwd_changed': ('Password changed', 'Message title'),
    'passwd_changed_explanation': ('You changed your password: Your browser will ask for a username and password.', 'Message text'),
    }

jam = {
    'add_new_jam_session': ('Add new jam session', 'link'),
    'jam_sessions': ('Jam sessions:', 'a list of jam session will listed after/under this label'),
    'jam_session': ('jam session', ''),
    'annotations': ('annotations', ''),
    'continue_with_version': ('Continue with your version', 'button label'),
    'artefact': ('artefact', ''),
    'viewing_annotations': ('viewing annotations', ''),
    'Annotations': ('Annotations:', 'Label, followed by a list of annotations under it'),
    'add_annotation': ('Add annotation', 'link'),
    'adding_new_jam_session': ('Adding new jam session', ''),
    'title_of_jam_session': ('Title of jam session', 'label'),
    'type_of_jam_session': ('Type of jam session', 'label'),
    'mutate_on_previous': ('Mutate on previous', 'type of jam session'),
    'explore_possibilities': ('Explore possibilities', 'type of jam session'),
    'diverge_and_converge': ('Diverge & Converge', 'type of jam session'),
    'description_of_jam_session': ('Description of jam session', 'label'),
    'upload_the_starting_artefact': ('Upload the starting artefact', 'label'),
    'name_of_the_starting_artefact': ('Name of the starting artefact', 'label'),
    'annotation_of_the_starting_artefact': ('Annotation for the starting artefact', 'label'),
    'adding_new_artefact': ('Adding new artefact', ''),
    'name_of_the_artefact': ('Name of the artefact', 'label'),
    'upload_file': ('Upload file', 'label'),
    'you_adding_annotation': ('You are adding annotation to the artefact', 'message in adding annotations form'),
    'adding_annotation': ('Adding annotation to', ''),
    'to_jam_session': ('to jam session', 'Part of a message'),
    'to_jam_artefact': ('to jam artefact', 'Part of a message'),
    'unread_artefacts': ('new artefacts', 'There is a number before this message'),
    'total_artefacts': ('artefacts', 'There is a number before this message'),
    'are_you_sure_jam_sessions': ('Are you sure you want to delete the following jam sessions:' , 'Message dialog message'),
    'censor_artefact': ('Censor artefact', 'Button label for censoring jam artefact'),
    'uncensor_artefact': ('Uncensor artefact', 'Button label for uncensoring jam artefact'),
    'censor_annotation': ('Censor selected annotations', 'Button label for censoring jam annotations'),
    'uncensor_annotation': ('Uncensor selected annotation', 'Button label for uncensoring jam annotations'),
    'censored_name': ('Censored', 'Title/name for censored jam artefact'),
    'censored_message': ('This artefact has been censored by %s at %s.', "First placeholder is replaced by censorer's name and the second by the date"),
    'censored_msg': ('Artefact is censored', 'Message shown when teacher censores an artefact.'),
    'censored_annotation_msg': ('Annotation is censored', 'Message shown when teacher censores an annotation.'),
    'censor_verify': ('Are you sure you want to censor this artefact? Your name and this date will be stored and displayed along with the censorship notice to everyone viewing this artefact.','Verification message shown when censoring is attempted'),
    'censor_annotations_verify': ('Are you sure you want to censor the annotations you selected? Your name and this date will be stored and displayed along with the censorship notice to everyone viewing annotations.','Verification message shown when censoring is attempted'),
    'censored_annotation_body': ('This annotation has been censored by %s at %s.',"Body for censored annotation. First placeholder is replaced by censorer's name and the second by the date"),
    }
    
ivacommon = {
  #editform.dtml - ZWiki 
  'ic_zwiki_change':('Change','Button - Change WikiPage contents'),

  'ic_zwiki_modifiers':('modified by','breadcrumbs'), #05.08
  'ic_zwiki_who_modified':('Who has been modifying it?','Heading'), #05.08
  'ic_zwiki_nobody_modified':('None has modified it','Message'), #05.08

  #jooksva_kursuse_nimi.dtml
  'ic_no_course_selected':('No course selected','Message - Course not selected'),
  #kasutajakursused_valik.dtml
  'ic_select_course':('Select course','Default menu option - Select course'),
  'ic_change_course':('Go','Button - Change course'),
  'ic_not_added_to_courses':('Not registered to any course','Message - Not registered to any course'),


  #Kirjakast.py #28.12
  'ic_nomail':('No unread mail','Message'),
  'ic_to':('To: ','Field name'),
  'ic_subject':('Heading: ','Field name'),
  'ic_text':('Body: ','Field name'),
  'ic_send':('Send','Button label'),
  'ic_newmail':('New mail','Left menu item'),
  'ic_mailbox':('Mailbox','Left menu item'),
  'ic_outbox':('Sent mail','Left menu item'),
  'ic_sender':('Sender','Table column heading'),
  'ic_title':('Subject','Table column heading'),
  'ic_sentdate':('Date','Table column heading'),
  'ic_select_whom':('Select receiver(s):','Text before pull-down menu'), #06.01.2004
  'ic_add_name':('Add','Button label'), #06.01.2004

  #ui/Note/content.dtml #06.01.2004
  'ic_delete_note':('Delete note','Link label'),

  #Course.py #28.12
  'ic_removed':('Removed','Message'),
  'ic_registered':('Registered','Message'),
  'ic_added_to_course':('You have been registered to the course','Body of mail message'),
  '':('',''),

  #Webtop/index_html.dtml #16.02 - by Mart
  'ic_make_public':('Publish','Button label - Publish object from Drawer to Portfolio'),
  'ic_tocalendar':('To calendar','Button label'), #08.10 Taavi
  'ic_eventmgt':('Event management','Left menu item'), #08.10 Taavi

  'ic_pack':('Zip','Button label'), #28.12
  'ic_loadzip':('Unzip','Button label'), #28.12
  'ic_adding_zip':('Uploading and unzipping a zip-file','Page heading'),  #28.12
  'ic_unzipped':('Zip-file has been uploaded and unzipped.','Message'), #28.12
  'ic_upload_zip':('Upload zip-file','Message before Browse-box'), #28.12
  'ic_advanced':('Advanced search','Link label'), #28.12
  'ic_search':('Search','Link label'), #28.12

  #ui/Webtop/wt_search.dtml #28.12 - by Taavi
  'ic_searching':('Searching','Title'), #28.12
  'ic_search_title':('Title: ','Field name'), #28.12
  'ic_search_owner':('Owner: ','Field name'), #28.12
  'ic_search_keyword':('Keyword: ','Field name'), #28.12
  'ic_cancel':('Cancel','Button label'), #28.12

  #ui/Webtop/wt_search_results.dtml #28.12 - by Taavi
  'ic_newsearch':('New search','Link label'), #28.12
  'ic_search_results':('Viewing the search results','Title'), #28.12
  'ic_result_type':('Type:','Column heading'), #28.12
  'ic_result_title':('Title:','Column heading'), #28.12


  #kaustadkursusel.dtml #16.02 - by Mart
  'ic_no_folders':('No folders','Message - No folders in this course'),
  'ic_course_info':('Course info','Left menu item - Course info'),
  
  #tootoad_kursusel.dtml #16.02
  'ic_knowledge_building_link':('Knowledge Building','Left menu item - Knowledge Building'),
  'ic_jamming_link':('Jamming','Left menu item - Jamming'),
  'ic_wiki_link':('Wiki','Left menu item - Wiki'),
  'ic_no_course_selected':('No course selected','Message - Course not selected'),

  #tootubade_leht.dtml #16.02 - 14
  'ic_workshops_1':('workshops','Breadcrumb - Workshops'),

  #test_opilane.dtml #16.02
  'ic_test_list':('Quizzes', 'Menu header - list of quizzes'),

  #halduseleht.dtml #16.02
  'ic_management_page':('management','Breadcrumbs'),
    
  #UserManager.py #05.10 Taavi
  'ic_firstname':('First name','Field name'),
  'ic_lastname':('Last name','Field heading'),
  'ic_username':('Username','Field heading'),
  'ic_try':('Try','Link label'),
  'ic_register':('Register','Link label'),
  'ic_forward':('Forward','Link label'),
  'ic_missingdata':('Not enough data','Error message'),
  'ic_upload':('Send','Submission button label'),
  'ic_adding_affil':('Adding affiliation codes','Page title'), #07.12.2004
  'ic_import_affil':('Load affiliation codes from text file','Subheading'), #07.12.2004
  'ic_course_changed':('In the course %s has been changed','Part of e-mail message'), #07.12.2004
  'ic_e_subject':('Changes in IVA course contents','Subject row for e-mail notification'), #07.12.2004
  'ic_email_1':('After your last visit to IVA, during the period ','First part of e-mail message'), #07.12.2004
  'ic_email_2':('there have been some changes in the content of some IVA courses, namely ','Second part'), #07.12.2004


  #opetaja_menyy.dtml
  'ic_user_management':('Participants','Left menu item - User management'),
  'ic_inner_group_management':('Subgroup management','Left menu item - Subgroup management'),
  'ic_test_management':('Quiz management','Left menu item - Quiz management'),
  'ic_course_management':('Course management','Left menu item - Course management'),
  'ic_eventmgt':('Event Management','Left menu item'), #08.10 Taavi
  'ic_addpending':('Add pending users','Left menu item'), #08.10 Taavi

  'ic_taskmgt':('Assignments','Left menu item'), #28.12

  #sisegrupi_lisamise_leht.dtml
  'ic_problem_in_adding_inner_group':('Error. Probably there is already a group with the same name.','Error message'),

  #sisegrupiloetelu.dtml #16.02
  'ic_inner_groups_list':('Subgroups','Left menu item - Subgroups'),
  
  #sisegrupi_lisamise_vorm.dtml  #16.02
  'ic_name_of_new_group':('Name of new subgroup','Form field - Name of new subgroup'),
  'ic_create_new_group':('Create','Button label - Create subgroup'),
  'ic_inner_group_management_3':('subgroup management','Breadcrumbs - Subgroup management'),
  'ic_adding_inner_group_2':('creating','Breadcrumbs - Creating subgroup'),

  #sisegrupikustutusvorm.dtml #16.02
  'ic_inner_group_management_4':('subgroup management','Breadcrumbs - Subgroup management'),
  'ic_inner_group_deleting':('deleting','Breadcrumbs - Deleting subgroup'),
  'ic_remove_inner_group':('Delete subgroup','Button label - Delete subgroup'),

  #sisegrupi_osaliste_vorm #16.02
  'ic_inner_group_management_5':('subgroup management','Breadcrumbs - subgroup management'),
  'ic_inner_group_participants':('members','Breadcrumbs - subgroup participants'),
  'ic_inner_group_other_course_participants':('Course participants','Table header - course participants'),
  'ic_inner_group_participants_in_group':('Subgroup members','Table header - list of subgroup participants'),
  'ic_inner_group_change_participants':('Change','Button label - Change subgroup member list'),

 
  #sisegrupihaldus.dtml
  'ic_inner_group_management_2':('subgroup management','Breadcrumbs - subgroup management'), #16.02
  'ic_adding_inner_group':('Add subgroup','Link label - Subgroup'),
  'ic_deleting_inner_group':('Delete subgroup','Link label - Delete subgroup'),
  'ic_managing_inner_group_users':('Subgroup members','Table header - Subgroup members'),
  'ic_list_subgroups':('List subgroups','Link label'), #28.12
     
  #tootoad_kursusel.dtml #05.10 Taavi
  'ic_grportfolio':('Subgroup portfolios','Left menu item'),

  #kasutajaotsing.dtml #05.10 Taavi
  'ic_finduser':('Search','Button label'),
  'ic_delete':('Delete','Button label'),
  'ic_perm':('Permissions','Button label'),
  'ic_perm_on':('Limited','UserInfo'),
  'ic_perm_off':('Unlimited','UserInfo'),
  'ic_perm_unset':('Unset','UserInfo'),
  'ic_usermgt':('user management','Breadcrumbs'),
  'ic_addusers':('Add users','Link label'),
  'ic_addaffiliation':('Add affiliation','Link label'),
  'ic_savecsv':('Save as CSV','Link label'),
  'ic_affiliation':('Affiliation','Link label'),
  'ic_select_all':('Select all','Link label'), #07.01.2004
  
  #veebilauaviited.dtml #05.10 Taavi
  'ic_portfolio':('Portfolio','Left menu item - Portfolio'),
  'ic_drawer':('Drawer','Left menu item - Drawer'),
  'ic_wiki':('Wiki','Menu item - Wiki'),
  'ic_logpage':('Logpage','Menu item'),

  #paevikuleht.dmtl #05.10 Taavi
  'ic_apply':('Open courses','Menu item'),

  #oigustePiiramine.dmtl #22.10 Taavi
  'ic_restrictac':('Restrict affiliation changing','Checkbox label'),
  'ic_restrictpc':('Restrict password changing','Checkbox label'),
  'ic_enforcepc':('Enforce password change','Checkbox label'),
  'ic_change':('Change','Link label'),

  #edit_user_form.dtml #22.10 Taavi
  'ic_browserprefs':('Follow browsers language preference: ','Link label'),
  'ic_sendtomail':('Send by e-mail: ','Field name'), #28.12
  'ic_messages':('internal mail messages','Checkbox label'), #28.12
  'ic_grades':('grades','Checkbox label'), #28.12
  'ic_changesbookshelf':('Bookshelf change notification','Checkbox label'), #28.12
  'ic_changeskb':('Knowledge Building change notification','Checkbox label'), #28.12
  'ic_changesjamming':('Jamming change notification','Checkbox label'), #28.12

  #CourseManager.py #05.10 Taavi
  'ic_error':('Error','Error message'),
  'ic_nocourse':('No course to register to','Message'),
  'ic_added':('Registered: ','Listing header'),
  'ic_quote':('Quote','Field heading'),
  'ic_logo':('Logo','Field heading'),
  'ic_status':('State','Field heading'),
  'ic_preparation':('Under construction','Pull-down menu item'),
  'ic_open':('Open for registration','Pull-down menu item'),
  'ic_closed':('Registration closed','Pull-down menu item'),
  'ic_finished':('Course finished','Pull-down menu item'),
  
  #FLE.py
  'ic_help':('Help','Button - Help on Main screen'), #16.02

  #hdr.dtml
  'ic_hdr_drawer':('drawer','Breadcrumbs - Drawer'),  #16.02 see ja jrgmised 4
  'ic_hdr_portfolio':('portfolio','Breadcrumbs - Portfolio'),
  'ic_hdr_context':('bookshelf','Breadcrumbs - Bookshelf'),
  'ic_hdr_workshop':('workshops','Breadcrumbs - Workshops'),
  'ic_hdr_management':('management','Breadcrumbs - Management'),
  'ic_hdr_inner_group_name':('subgroup','Breadcrumbs - Subgroup'),

  #kasutajateemataust.dtml #07.04 Jaagup
  'ic_t_webtop':('Your personal desktop on the Web','Picture alt text'),
  'ic_t_context':('Course context prepared by tutor','Picture alt text'),
  'ic_t_workshop':('Collaboration tools','Picture alt text'),
  'ic_t_management':('Management of courses, users, subgroups and quizzez','Picture alt text'),
  'ic_t_':('','Picture alt text'),
  'ic_t_':('','Picture alt text'),
  
  #ui/CourseManager/index_html.dtml #05.08
  'ic_add_users':('User management','Link'),

  #ui/CourseManager/course_info_content.dtml #28.12
  'ic_imail':('Send internal mail to all students','Link label'),#28.12
  'ic_archive':('Archive the course','Link label'),#28.12 

  #ui/Course/index_html.dtml #16.02
  'ic_kb_1':('knowledge building','Breadcrumbs - Knowledge Building'),
  'ic_export':('Export the course','Link label'), #28.12
  'ic_changestatus':('Change status','Button label'), #28.12

  #ui/Jamming/index_html.dtml #16.02
  'ic_jam_1':('jamming','Breadcrumbs - Jamming'),

  #standard_wiki_footer.dtml #16.02
  'ic_change_wiki_page':('Edit page','Link label - Edit page'),
  'ic_add_wiki_comment':('Add comment','Button label - Add comment'),
  'ic_wiki_export':('Export','Link label'),#28.12
  '':('',''),

  #menu images  #kasutajateemataust.dtml hdr.dtml #16.02
  'ic_picture_webtop_1':('webtop1_en','Upper menu item picture filename'),
  'ic_picture_webtop_2':('webtop2_en','Color bar header picture filename'),
  'ic_picture_bookshelf_1':('bookshelf1_en','Upper menu item picture filename'),
  'ic_picture_bookshelf_2':('bookshelf2_en','Color bar header picture filename'),
  'ic_picture_management_1':('management1_en','Upper menu item picture filename'),
  'ic_picture_management_2':('management2_en','Color bar header picture filename'),
  'ic_picture_workshops_1':('workshops1_en','Upper menu item picture filename'),
  'ic_picture_workshops_2':('workshops2_en','Color bar header picture filename'),

  #Cruft.py
  'ic_user_not_found':('User not found','message'), #29.03
  'ic_no_user_data_in_this_course':('user has no data in this course','message'),
  'ic_no_events_for_user':('User has no events to report on this course','message to the viewer of event'),

  'ic_info_user_name':('Username','Table column heading'), #01.04
  'ic_info_number_open_pages':('Viewed','Table column heading'),
  'ic_info_added_kb_notes':('Posted','Table column heading'),
  'ic_info_read_kb_notes':('Read','Table column heading'),
  'ic_info_added_jamming_artefacts':('Media files','Table column heading'),
  'ic_info_test_results':('Quizzes','Table column heading'),
  'ic_info_last_access':('Last access','Table column heading'),
  'ic_info_total_mark':('Total grade','Table column heading'),
  'ic_info_comment':('Comment','Table column heading'),
  'ic_info_save':('Save','Button label'),

  'ic_mail_to_all':('Send e-mail to whole group', 'Link label'), #07.04 Jaagup
  'ic_course_statistics':('Course statistics', 'Link label'),
  'ic_user_adding':('creating users','Breadcrumbs'), #05.08
  'ic_user_names':('Usernames to register','Heading'), #05.08
  'ic_user_create':('Create','Button label'),#05.08

  'ic_copy1':('copy', 'part of label'), #28.12 
  'ic_copy2':('copy', 'part of label'), #28.12

  #kylastajateLoetelu (WebtopFolder.py)  #05.04 Mart
  'ic_name':('Who','Table column heading'),
  'ic_date':('When','Table column heading'),  
  'ic_nobody_read':('Nobody has viewed this obejct yet','Message text'),
  'ic_viewed_by':('Who has been viewing it?','Page heading'),
  'ic_viewers':('viewers','Breadcrumbs'),

  #UserInfo.py
  'ic_month_jan':('January', 'Calendar month'),  #15.09.03 Jaagup
  'ic_month_feb':('February', 'Calendar month'),
  'ic_month_mar':('March', 'Calendar month'),
  'ic_month_apr':('April', 'Calendar month'),
  'ic_month_may':('May', 'Calendar month'),
  'ic_month_jun':('June', 'Calendar month'),
  'ic_month_jul':('July', 'Calendar month'),
  'ic_month_aug':('August', 'Calendar month'),
  'ic_month_sep':('September', 'Calendar month'),
  'ic_month_oct':('October', 'Calendar month'),
  'ic_month_nov':('November', 'Calendar month'),
  'ic_month_dec':('December', 'Calendar month'),
  'ic_author':('Author', ''),
  'ic_time':('Time', ''),
  'ic_enter_correct':('Enter correct ', ''),

  'ic_hide':('Hide', 'Button label'), #28.12
  'ic_hiddenevents':('Hidden events', 'Button label'), #28.12  

}

ivatests = {
  #Prefix it - Iva Test
  #YlTest.py
  'it_qt_public':('Public','Test status'),
  'it_qt_closed':('Closed','Test status'),
  'it_qt_between':('Limited','Test status'),
  'it_qt_status':('Status','Test status button'),
  'it_save_title':('Save quiz settings','Button label - Save the title of quiz'),
  'it_description_of_permissions':('Permissions','Header - Description of permissions'),
  'it_all_permission':('anyone','Link label - All course participants can solve the quiz'),
  'it_inner_groups_permission':('subgroups','Link label - Inner groups which participants can solve quiz'),
  'it_user_permission':('persons','Link label - Users who have permission to solve quiz'),
  'it_add_user_permission':('Add','Button label -  add user permission'),
  'it_add_group_permission':('Add','Button label - add group permission'),
  'it_question':('Question','Table header - Question in page creating quiz'),
  'it_answer':('Answer','Table header - '),
  'it_type':('Type','Table header - Type'),
  'it_deletion':('Delete','Button label - select for deleting'),
  'it_points':('Points','Table header - maximum points for this questions'),
  'it_change':('Change','Table header - Change exercise in test'),
  'it_delete_exercise':('Delete','Button label - Delete'),
  'it_make_public':('Release','Link label - Make test available for students'),
  'it_hide':('Hide','Link label - Hide quiz'),
  'it_add_exercise':('Add question','Link label - Add question'),
  'it_results_from_users':('Submissions','Link label - list of students who and how solved test'),
  'it_import_from_hotpotatoes':('Import','Link label - Import as text file'),
  'it_export_to_web_ct':('Export','Link label - Export to text file'),
  'it_solving_test':('Solving quiz %s','Header - solving the quiz'),
  'it_save_solved_test':('Save answers','Button label - Save quiz answers'),
  'it_answers_saved':('Answers submitted','Message - Quiz answers saved'),
  'it_answer_instance':('Solution no.','Heading'),
  'it_quiz_responses':('Answers','Header - List of submissions'),
  'it_hdr_tests':('quizzes','Breadcrumbs'),  #16.02
  'it_problem_in_finding_users':('could not find user(s)','Message'),
  'it_delete_permission':('Delete','Button label - Delete permissions'),
  'it_an_question':('Question','Table header - Question in user answer list page'),
  'it_an_user_answer':('Responses','Table header - '),
  'it_an_answer_commenting_table':('Add comments','Link label'),  #16.02
  'it_an_teacher_answer':('Correct answer','Table header - Correct answer from teacher'),
  'it_an_result':('Correct','Table header - Checked if answer right'),
  'it_an_points':('Score','Table header - Score'),
  'it_an_comment':('Comment','Table header - comment from teacher'),
  'it_anc_question':('Question','Table header - Question in commenting answers page'),
  'it_anc_user_answer':('Student response','Table header - Student response'),
  'it_anc_teacher_answer':('Correct answer','Table header - Result suggested by teacher'),
  'it_anc_result':('Correct','Table header - Is answer correct'),
  'it_anc_automatic_points':('Calculated total','Table header - Automatically calculated total score'),
  'it_anc_teacher_points':('Final','Table header - Points added by teacher'),
  'it_anc_nominal_points':('Max', 'Table header - How many points for the right answer'),
  'it_anc_teachers_comment':('Comment','Table header - Comment from teacher'),
  'it_anc_point_reading':('Included','Table header - Does teacher add points from this exercise to quiz total score'),
  'it_anc_comment_to_whole_answer':('General comment','Header - Teachers comment to the students quiz result in general'),
  'it_anc_save':('Save','Button label - Save points and comments'),
  'it_no_percent_calculating':('Percentage not calculated','Message - Percentage not calculated, because no nominal points in this test.'),
  'it_test_answers':('Submissions for quiz %s','List heading - Quiz submissions'),
  'it_tests':('quizzez','Breadcrumbs - Quizzes'),
  'it_answers':('responses','Breadcrumbs - Responses'),

  'it_open_test':('Make quiz public','Link label - make quiz public for all students'), #29.03
  'it_opened_for_all':('Anyone','message in the list of quizzes'), #29.03
  'it_add_group_permission':('add','link label - give quiz solving permission to a group'), #29.03
  'it_add_personal_permission':('add','link label - give quiz solving permission to a person'), #29.03
  'it_delete_permission':('remove','Button label - remove permission'),
  'it_no_users_without_permission':('Everybody has permission to solve the quiz','message'), #29.03
  'it_no_groups_without_permission':('All groups have permission to solve the quiz','message'), #29.03

  'it_click_to_save':('You must click the button <Save answers> in order to submit your answers. Return to previous page by clicking the Back-button of your browser.','Message text'), #28.12
  'it_type_quiz':('Quiz','Type of the test, pull-down menu item'), #28.12
  'it_type_selftest':('Selftest','Type of the test, pull-down menu item'), #28.12
  'it_type_survey':('Survey','Type of the test, pull-down menu item'), #28.12
  'it_quiz_title':('Heading','Field name'), #28.12
  'it_quiz_descr':('Description','Field name'), #28.12
  'it_quiz_type':('Type','Field name'), #28.12

  'it_warning_quiz':('Attention! Continue only if you want to solve the quiz NOW. ','Warning message - you are about to begin the quiz'),  #28.12 
  'it_quiz_started':('Quiz was started at: ','First part of a message'),  #28.12
  'it_begin_quiz':('Begin the quiz','Button label'),  #28.12
  'it_quiz_stats':('Statistics','Link label'),  #28.12
  'it_selftest_submit':('Submit answer','Button label'),  #28.12
  'it_selftest_end':('End of self-test','Message'),  #28.12
  'it_selftest_next':('Continue','Button label'), #28.12
  'it_stat_choice':('Choice','Field label'), #28.12
  'it_stat_count':('Count','Field label'), #28.12
  'it_stat_hits':('Hits','Field label'), #28.12
  'it_stat_err':('Invalid data','Field label'), #28.12
  'it_editing_quiz':('Editing the quiz','Page heading'), #28.12
  'it_totalpoints':('Total points: ','Part of message'), #28.12
  'it_grading':('Grading','Link label'), #28.12
  'it_ca_onclosing':('only after the quiz has been closed','Pull-down menu item'), #28.12
  'it_ca_always':('always','Pull-down menu item'), #28.12
  'it_ca_never':('never','Pull-down menu item'), #28.12
  'it_ca_visible':('Correct answers are shown to students: ','Message before pull-down menu'), #28.12
  'it_editing_settings':('Changing the quiz settings','Page heading'), #28.12
  'it_submissions':('Submitted: ','Field label'), #28.12
  'it_no_stats':('No statistics','Message'), #28.12
  'it_stat_scored':('Number of students who scored: ','Part of a message'), #28.12
  'it_stat_total':(', total sum of points: ','Part of a message'), #28.12
  'it_stat_notempty':('Number of responses: ','Part of a message'), #28.12

  'it_restrictions':('Restrictions','Link label'), #07.01.2004
  'it_notpublic':('Not public yet','Button label'),#07.01.2004
  'it_for_all':('Open for all','Button label'),#07.01.2004
  'it_for_subgroups':('Open for subgroups','Button label'),#07.01.2004
  'it_for_persons':('Open for persons','Button label'),#07.01.2004
  'it_you_answered':('You answered: ','Message'),#07.01.2004
  'it_feedback':('Feedback','Message'),#07.01.2004
  'it_right_answer':('Right answer: ','Message'),#07.01.2004
  'it_excercise':('Excercise','Page heading'),#07.01.2004

 #kasutajateTulemused - testitulemuste kuvamise leht
  'it_show_comments':('Show comments','Link label'), #05.04 Mart
  'it_hide_comments':('Hide comments','Link label'), #05.04 Mart

 #lubadeViited 
  'it_timelimit':('timelimit','Link label'), #05.04 Mart 

 #koigiLuba - testi piirangute seadmise vorm
  'it_start_time':('Starting','Table column heading'), #05.04 Mart
  'it_end_time':('Ending','Table column heading'), #05.04 Mart
  'it_repeat':('Repeated','Table column heading'), #05.04 Mart
  'it_unlimited':('Unlimited','Table column heading'), #05.04 Mart
  'it_save':('Save','Button label'),  #05.04 Mart

  '':('',''),
  '':('',''),  
  #testihaldus.dtml #16.02 - by Mart
  'it_add_test':('Add quiz','Menu item - Add quiz'),
  'it_tests_bread':('quizzes','Breadcrumb'),
  'it_test_select':('Select','Table column heading'),
  'it_test_id':('ID','Table column heading'),
  'it_test_name':('Title','Table column heading'),
  'it_test_ready_to_solve':('Availability','Table column heading - is it available for students'),
  'it_test_rename':('Settings','Button label'),
  'it_test_delete':('Delete','Button label'),
  'it_test_export':('Export','Button label'),
  'it_test_import':('Import','Button label'),

  'it_test_randomized':('Randomized','Table column heading'), #05.04
  'it_test_submissions':('Submissions','Table column heading'), #05.04
  'it_test_randomize':('Randomize','Button label'), #05.04

  'it_test_type':('Type','Table heading'), #28.12

  '':('',''),

                      
                        
  #YlAlus.py
  'it_incorrect_point_count':('Invalid score','Message - Invalid quiz score'),
  'it_ex_question':('Question','Heading before question field'),
  'it_ex_save':('Save','Button label - Save question'),
  '':('',''),
  #'it_no_point_calculating':('n/a','Message - Total score is not calculated for this quiz'),
  'it_link_url':('Link URL','Heading before URL field'),
  'it_link_text':('Link text','Heading before URL title field'),
  'it_delete_picture':('Delete','Heading of checkbox - select picture for deleting'),
  'it_no_automatic_point_calculating':('n/a','No automatic calculation of score'),
  'it_nominal_points':('Maximum number of points for this question','Heading before MaxPoints field - The highest possible score'),
  'it_no_link_address':('Address missing','Message - Address missing'),
  'it_incorrect_URL':('Invalid URL','Message - Invalid URL'),
  'it_describing_text':('Optional introduction text', 'Form item label'), #29.03

  'it_picture':('Image','Form item label'), #05.04 Mart

  #YlTyybid.py
 # 'it_incorrect_answer':('Incorrect answer',''),
  'it_no_saved_answer':('Answer not saved','Message - Answer not saved'),
  'it_no_answer_text':('Missing answer','Message - Answer text missing'),
  'it_no_choices':('Missing choices','Message - Missing answer choices'),
  'it_no_answer':('Missing correct answer','Message - Missing correct answer'),
  'it_no_choices_in_viewing':('Missing choices','Message - Missing answer choices'),
  'it_problem_with_data':('Data error','Message - Problem with question data'),
  'it_one_answer':('Correct answer','Header - Correct answer'),
  'it_correct_answers':('Correct answers','Header - Correct answers'),

  #The types of quiz items in the pull-down menu #29.03
  'it_check_exercise':('Yes/No','Question type - binary, checkbox'), #16.02 lesannete nimetused
  'it_text_answer_exercise':('Paragraph','Question type - paragraph'),
  'it_one_answer':('Short answer','Question type - short answer'),
  'it_multiple_choice_exercise':('Mark all correct','Question type - mark all correct options'),
  'it_one_answer_exercise':('Multiple choice','Question type - Multiple choice'),

  'it_number_space_exercise':('Numerical','Question type - numerical'), #29.03 
  'it_percent_excercise':('Percent','Question type - percent calculation'), #29.03
  'it_matching_exercise':('Matching','Question type - matching'), #29.03
  '':('',''),

  #Multiple answers #05.08
  'it_ov_variant':('Responses','Table heading'),
  'it_ov_explanation':('Feedback','Table heading'),
  'it_ov_correct':('Correct','Table heading'),
  

  
  #Multiple choice #05.08
  'it_yv_variants':('Responses','Table heading'),
  'it_yv_explanation':('Feedback','Table heading'),
  'it_yv_correct':('Correct','Table heading'),

  '':('',''),



  #Numerical item settings, #29.03
  'it_av_min_correct':('Minimum','Table heading: lower limit of accepted range'),  
  'it_av_centre_correct':('Exact','Table heading: exact answer'), 
  'it_av_max_correct':('Maximum','Table heading: upper limit of accepted range'), 
  'it_av_checking_type':('Scoring options','Question before menu options'), 
  'it_av_space':('Range','Menu option. Maximum score if answer falls anywhere within the range'),
  'it_av_linear':('Gradual','Menu option. Score given depends on distance from exact answer.'),

  #Percent calculation item settings, #29.03
  'it_pr_solvents':('water; destilleeritud vesi','List of default solvents, separated with semicolon'), 
  'it_pr_soluble':('salt; sugar','List of default solubles, separated with semicolon'),
  'it_pr_term_solution_percent':('Strength of solution','Text, used in several contexts: Strength of solution'),
  'it_pr_term_solvent_amount':('Amount of solvent','Text, used in several contexts: amount of solvent'),
  'it_pr_term_soluble_amount':('Amount of soluble','Text, used in several contexts: amount of soluble'),
  'it_pr_term_soluble_to_solvent':('Soluble/Solvent','Text, used in several contexts'),
  'it_pr_term_asking_answer':('Variable to be found','Comment to solver'),
  'it_pr_soluble_amount_space':('Accepted range of amount of soluble','Label on the page of entering the question: range'),
  'it_pr_solvent_amount_space':('Accepted range of amount of solvent, measure','Label: range'),
  'it_pr_soluble_names':('Name of soluble, measure','Label: soluble name and measurement unit'),
  'it_pr_solvent_names':('Name of solvent, measure','Label: solvent name and measurement unit'),
  'it_pr_answer_exactitude_percent':('Accuracy of answer','Label on the page of entering the question'),
  'it_pr_answer_type':('Type of answer','Label on the page of entering the question: searchable'),
  'it_pr_checking_type':('Scoring options','Question before menu options'),
  'it_pr_space':('Range','Menu option: Maximum score if answer falls anywhere within the range'),
  'it_pr_linear':('Gradual','Menu option: Score given depends on distance from exact answer'),
  '':('',''),
  '':('',''),

  #Matching #05.08
  'it_mt_left':('Left column','Table heading'),
  'it_mt_right':('Right column','Table heading'),


  #YlVahendus.py
  'it_send_text':('Import','Button label - Import quiz as text'),
  'it_send_file':('Import','Button label - Import quiz as textfile'),

  'it_choosing_exercise_type':('Add new question','Heading - Select question type'), #16.02

  'it_check_exercise_default_question':('Question text','Default binary question heading'),     #16.02 jj
  'it_text_answer_exercise_default_question':('Question text','Default paragraph question heading'), #29.03
  'it_one_answer_default_question':('Question text','Default short answer question heading'), #29.03
  'it_multiple_choice_exercise_default_question':('Question text','Default mark-all-correct question heading'), #29.03
  'it_one_answer_exercise_default_question':('Question text','Default multiple choice question heading'), #29.03

  'it_percent_exercise_default_question':('Find the missing component','Default percent question heading'), #29.03
  'it_matching_exercise_default_question':('Match the pairs','Default matching question heading'), #29.03
  'it_number_space_exercise_default_question':('Question text','Default numerical question heading'), #29.03

  '':('',''),
}

#New module added #07.09 by Taavi

ivaevents = {
  'ie_incomplete':('Incomplete','Pull-down menu item, incomplete event'),
  'ie_delete':('Delete','Submit button label, delete selected events'),
  'ie_complete':('Complete','Pull-down menu item, complete event'),
  'ie_own':('Personal','Property of an event, inside of table listing'),
  'ie_name':('Name','Field name - Name of event'),
  'ie_teaser':('Teaser','Field name - Short description of event'),
  'ie_body':('Body','Field name - Full description of event'),
  'ie_starttime':('Starting time','Field name - Starting time of event'),
  'ie_endtime':('Ending time','Field name - Ending time of event'),
  'ie_link':('Link','Field name - Link label'),
  'ie_attached':('Attachment','Field name - Attachment'),
  'ie_status':('Status','Field name - Status'),
  'ie_change':('Change','Link label - Change event'),
  'ie_save':('Save','Button label - Save event description'),
  'ie_addevent':('Add event','Link label'),
  '':('',''),
  '':('',''),
}

#New module added #28.12 by Mart

ivatasks = {

#Kodutoo.py 
  'ia_addtask':('Add assignment','Link label'),
  'ia_grading':('Grade assigments','Link label'),
  'ia_title':('Title','Table column heading'),
  'ia_type':('Type','Table column heading, also field label'),
  'ia_points':('Points','Table column heading'),
  'ia_total':('Total points:','Field label'),
  'ia_delete':('Delete','Button label'),
  'ia_grade_labels':('Grade','Table column heading'),
  'ia_grade_percent':('Limit %','Table column heading'),
  'ia_submit':('Save','Button label'),
  'ia_add':('Add','Button label'),
  'ia_quiz':('Quiz','Pull-down menu item'),
  'ia_product':('Product','Pull-down menu item'),
  'ia_grpwork':('Groupwork','Pull-down menu item'),
  'ia_presentn':('Presentation','Pull-down menu item'),
  'ia_select_quiz':('Select quiz','Default option in pull-down menu'),
  'ia_descr':('Description','Field label'),
  'ia_deadline':('Deadline','Field label'),
  'ia_edit':('Edit','Button label'),
  'ia_editing_task':('Editing the settings of the assignment','Page heading'),
  'ia_adding_task':('Adding the assignment','Page heading'),
  'ia_groups':('Groups: ','Field label'),
  'ia_result':('Result','Table column header'),
  'ia_noscale':('No scale','Error message - grading scale is missing'),
  'ia_nogrades':('No grades','Error message - grades are missing'),
  'ia_failed':('Failed','Error message - grade below satisfactory'),

  'ia_task':('Task','Title'),#07.01.2004
  'ia_deadline_updated':('Deadline updated: ','Message'),#07.01.2004
  'ia_no_deadline':('No deadline','Message'),#07.01.2004
  'ia_task_added':('New task added','Message'),#07.01.2004


#Course.py
  'ia_total_grade':('Grade','Table column heading'),
  'ia_no_folder':('Folder missing','Error message within the table'),
  'ia_gradetable':('Grade table','Page heading'),
  'ia_comment':('Comments','Table column heading'),
  'ia_scale':('Scale','Table column heading'),
  'ia_view':('View','Link label'),
  'ia_maxpoints':('Max: ','Field label'),
  'ia_none':('none','Message'),#07.01.2004
  'ia_savecsv':('Save as CSV-file','Link label'), #07.01.2004
  'ia_email_grades':('Distribute grades by e-mail','Checkbox label'), #07.01.2004
  'ia_grademail_subject':('Your grade','Subject of e-mail message with grade'), #07.01.2004
  'ia_grademail_body1':('Your final grade on the course ','Part of e-mail message with grade'), #07.01.2004
  'ia_grademail_body2':('is: ','Part of e-mail message with grade'), #07.01.2004
  '':('',''),


#WebtopFolder.py #07.01.2004
  'ia_edit_deadline':('This folder can be edited until: ','Part of a message - Allowed to edit until:'),


#UserInfo.py #07.01.2004
  'ia_tasks':('Assignments','Folder name'),

}


# All vocabularies combined
vocabulary = {'common': common,
              'kb': kb,
              'webtop': webtop,
              'usermgmnt': usermgmnt,
              'coursemgmnt': coursemgmnt,
              'jam': jam,
              'ivacommon': ivacommon,
              'ivatests': ivatests,
              'ivaevents': ivaevents, #07.09
		  'ivatasks': ivatasks, #28.12
              }
              
#print vocabulary['ivatests']['it_send_file']

#EOF
