# $Id: vocabulary_fi.py,v 1.4 2003/12/27 07:44:24 martl Exp $
#
# Copyright 2003 by IVA Team and contributors
#
# This file is part of IVA.
#
# IVA is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# IVA is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with IVA; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

"""Contains the Finnish translations for all IVA printable strings."""

# How to do a new translation:
#
# 1. Copy this file into a new file, appending the language code after it, so
# you get something like "vocabulary_es.py" for Spanish and so on.
#
# 2. Edit the new file, translating the second portion of each line. The
# first portion is the keyword, which you shouldn't touch. The second is the
# translation that should be translated to the target language. The third
# is the supplementary instruction, that should help you do the translations.
#
# 3. Please note that the file is in Python code and needs to follow certain
# syntax rules:
#  - Strings can either be quoted by singles quotes (') or double quotes (").
#    If you need to use either of these quotation marks in your translation,
#    make sure that you use the other quotation mark to surround the string.
#    If you need to use both quotation marks in the same translation string,
#    you can surround the string with triple quotes (''' or """), which
#    allows you to use either of the quotation marks inside the string.
#  - Line breaks are not allowed inside strings, so make sure you don't
#    use an editor that wraps lines. You can have line breaks between
#    strings, though.
#
# 4. If you need to use special characters (outside of the 127 character
# ASCII range), you have several choices:
#
# A. Write in your native encoding (whatever suits you best). This requires
#    that you change the "charset_encoding" keyword in the "common" module to
#    the encoding type you will use. This document is written in iso8859-1,
#    although as english does not contain special characters, it could be
#    in utf-8 as well without any differences.
#    Most European languages are easiest to write in iso8859-1.
#
# B. Write in utf-8 encoded unicode. If your editor can save files in utf-8,
#    use that feature. If not, you can add the special characters manually
#    with the \x escape sequences. Make sure you remove the keyword
#    "charset_encoding" from the "common" module, or change its value to
#    "utf-8" so that the strings are interpreted correctly.
#    'key': ('\xe3\x82\xaa','This is the katakana letter O,encoded in utf-8.'),
#
# C. Write in unicode. Each unicode string starts with u followed by the
#    quotes. Each unicode character starts with \u followed by the code in
#    hexadecimal notation. The value of the "charset_encoding" keyword
#    is irrelevant if you use unicode all the way.
#    'key': (u'\u30aa','This is the katakana letter O, encoded in unicode.'),
#
# 5. Check your translation. If you have Python installed and you've
#    downloaded IVA sources, you can execute "python TranslationLint.py"
#    which will check through all the translation files and will produce
#    an error if there is a syntax error.
#    If you have installed IVA, you can test the translation yourself
#    by going to Zope Management and selecting the Tools tab in your IVA
#    instance, and clicking on "reload_translations". After this you
#    should be able to select your translation from user preferences
#    and see the translated strings.
#

common = {
    'language_name': ('Suomi', 'Name of this language'),
    'charset_encoding': ('ISO-8859-1','Encoding used in this translation (if missing, utf-8 is assumed'),
    'WebTop': ('Verkkopyt','Main tab for webtop'),
    'Knowledge_Building': ('Tiedonrakentelu','Main tab for knowledge building'),
    'Course_Management': ('Kurssihallinta','Main tab for course management'),
    'User_Management': ('Osallistujat','Main tab for user management'),
    'Jamming': ('Jammailu', 'Main tab for jamming'),
    'Type_Management': ('Tietmystyyppihallinta','Heading'),
    'cancel': ('Peru','Button label'),
    'submit': ('Lhet','Button label'),
    'remove': ('Poista','Button label'),
    'next': ('Seuraava ->','Label for button'),
    'previous': ('<- Edellinen','Label for button'),
    'quick_submit': ('Tallenna nyt',''),
    'ok': ('Ok','Button label'),
    'webtop': ('Verkkopyt',''),
    'bookshelf': ('Kirjahylly',''),
    'description': ('Kuvaus','Label'),
    'short_date_format_display': ('PP.KK.AAAA', 'String displayed as clue when entering a date'),
    'short_date_format': ('%d.%m.%Y', 'Format string for short dates.'),
    'timestamp_format': ('%H:%M %d.%m.%Y', 'Format string for long timestamps.'),
    'invite': ('Kutsu',''),
    'add': ('Lis',''),
    'today': ('Tnn',''),
    'yesterday': ('Eilen',''),
    'groupfolder': ('-kurssin kansio','Heading'),
# v1.9:
    'dtml_reloaded': ('DTML on uudelleenladattu','Title for message dialog'),
    'dtml_files_reloaded': ('Tmn olion DTML-tiedostot on uudelleenladattu','Message dialog text'),
    'dtmls_reloaded': ('DTML:t on uudelleenladattu','Title for message dialog'),
    'dtmls_files_reloaded': ('Kaikki DTML-tiedostot on uudelleenladattu','Message dialog text'),
    'css_reloaded': ('Tyylitiedostot on uudelleenladattu','Title for message dialog'),
    'css_files_reloaded': ('Tmn olion tyylitiedostot on uudelleenladattu','Message text'),
    'error': ('Virhe',''),
    'warning': ('Varoitus',''),
# v1.26:
    'invalid_url': ('Virheellinen URL (WWW-osoite)','Message title'),
    'give_valid_url': ('Anna kelvollinen URL (WWW-osoite)','Message text'),
    'invalid_name': ('Nimi ei kelpaa','Message title'),
    'give_valid_name': ('Anna kelvollinen nimi','Message text'),
    'name_taken': ('Nimi %s on jo kytss. Valitse toinen nimi.','Message text, name inserted inside'),
# v1.31:
    'edit': ('Muokkaa','Button label'),
    'you_are_in': ('Sijaintisi:', 'Heading, without trailing colon - keep in translation if needed'),
    'required_field_missing': ('Et tyttnyt kaikkia pakollisia kentti.', 'Erro message text'),
    'confirmation': ('Varmistus', 'Title for confirmation dialogs'),
    'invalid_input': ('Virheellinen syte', 'Message title'),
    'invalid_fields': ('Seuraavat kentt sisltvt virheellist sytett', 'Message text followed by a list of field names'),
    'select_item_first_common': ('Valitse ainakin yksi elementti', 'Message text'),
    'link_to_webtop': ('Linkit verkkopydlle','Link'),
    'proxy_to_webtop': ('Linkit kurssikansio verkkopydlle','Link'),
    'export': ('Vie','Button label'),
    'import': ('Tuo','Button label'),
    'importing': ('Tuodaan','Heading start'),
    'megabyte': ('MB', 'Abbreviation for megabyte'),
    'kilobyte': ('kB', 'Abbreviation for kilobyte'),

    'logout': ('Kirjaudu ulos','Link for logging out, also heading in logout dialogs'),
    'logout_pre': ('Voit kirjautua ulos sulkemalla selaimesi.','Instructions on logging out'),
    'logout_post': ('Olet kirjautunut ulos','Logout notification'),
    'login': ('Kirjaudu sisn','Link to log in')
    }

kb = {
    'course_info': ('Kurssin tiedot','Label for link to course details'),
    'create_context': ('Luo kurssiosuus','Link to create new course context'),
    'hide_context': ('Piilota osuus','Link to hide a context from view'),
    'show_context': ('Nyt osuus','Link to show a hidden context'),
    'new_notes': ('uutta viesti','Label for showing the number of new notes, eg. "5 new notes"'),
    'notes_total': ('viesti','Label for showing the number of notes'),
    'full_description': ('koko kuvaus...', ''),
    'course': ('kurssi','String <course> in context display'),
    'context': ('osuus','String <context> in context display'),
    'thread': ('keskustelu','String <thread> in context display'),
    'note': ('viesti','String <note> in context display'),
    'start_new_thread': ('Aloita uusi keskustelu','Link'),
    'short_description': ('Lyhyt kuvaus','Label'),
    'long_description': ('Pitk kuvaus','Label'),
    'full_description': ('Koko kuvaus','Label'),
    'select': ('Valitse','Start of sentence, followed by a drop-down list of available knowledge types'),
    'knowledge_type': ('tietmystyyppi','Label'),
    'reply': ('Vastaa','Button label'),
    'show_notes': ('Jrjest viestit','Heading start'),
    'show_thread': ('keskusteluna','heading finish'),
    'show_type': ('tietmystyypin...','heading finish'),
    'show_author': ('kirjoittajan...','heading finish'),
    'show_date': ('ajan mukaan','heading finish'),
    'change_course_to': ('Valitse kurssi','Label, followed by a drop-down list of available courses'),
    'creating_context': ('Kurssiosuuden luominen kurssilla ','Title, followed by the course name'),
    'editing_context': ('Kurssiosuuden muokkaaminen','Title, followed by the course name'),
    'title_of_context': ('Kurssiosuuden nimi','Label'),
    'type_set': ('Tietmystyyppijoukko','Label'),
    'creating_note_in': ('Viestin luominen kurssiosuudelle','Title, followed by course context name'),
    'course_context': ('kurssiosuus','Label for course context'),
    'you_are_replying_to': ('Olet vastaamassa viestiin','Label'),
    'title_of_note': ('Otsikko','Label'),
    'message_body': ('Viestin sislt','Label'),
    'current_image': ('Nykyinen kuva','Label'),
    'replace_with': ('Korva kuvalla','Label for image replacement in note edit'),
    'add_image': ('Lis kuva','Label'),
    'title_of_image': ('Otsikko kuvalle','Label'),
    'add_link': ('Lis linkki (URL)','Label'),
    'title_of_link': ('Otsikko linkille','Label'),
    'preview': ('Esikatsele','Button label'),
    'previewing_note': ('Viestin esikatselu kurssiosuudessa ','Title/heading, followed by course context name'),
    'publish': ('Julkaise','Button label'),
# v1.19:
    'you_didnt_select_type': ('Et valinnut tietmystyyppi.','Title'),
    'go_back': ('Palaa takaisin','Start of message, rendered into a link'),
    'and_select_type': ('ja valitse viestiisi tietmystyyppi.','Rest of message'),
    'inline_notes': ('Nyt viestien sisllt','Link'),
    'outline_notes': ('Nyt vain otsikot','Link'),
    'view_info': ('tietojen katselu','Part of location bar'),
    'edit_context': ('Muokkaa kurssiosuutta','Link'),
# v1.27:
    'to_note': ('viestiin','Part of a message'),
# v1.31:
    'full_thread_no': ('Nyt vain aloitusviestit', 'Link'),
    'full_thread_yes': ('Nyt koko keskustelu', 'Link'),
    'censor': ('Poista viesti','Button label for censoring notes'),
    'uncensor': ('Palauta viesti','Button label for uncensoring notes'),
    'censored_msg': ('Viesti poistettu','Message shown when teacher censores a note.'),
    'censor_verify': ('Oletko varmaa, ett haluat poista viestin?','Verification message shown when censoring is attempted'),
    'censored_subject': ('Poistettu','Title/subject for censored notes'),
    'censored_body': ('Tmn viestin on poistanut %s (%s).','Body for censored messages. First placeholder is replaced by censorers name and the second by the date'),
    'notes_from_day': ('Viestit lhtien','Start of heading, followed by a date'),
    'previous': ('Edellinen','Link label'),
    'next': ('Seuraava','Link label'),
    'who_has_read': ('Kuka on lukenut tmn viestin?','Link label'),
    'last_read': ('Viimeksi lukenut','Label'),
    'times_read': ('Lukenut kertaa', 'Label'),
    'back': ('< takaisin','Link label'),
    'unread_to_read_msg': ('Kaikki viestit sikeess on merkitty luetuiksi.', 'title and message in a message dialog'),
    'mark_notes_read': ('Merkitse kaikki viestit luetuiksi', 'text in a button'),
    'creating_groupfolder': ('Luodaan uutta kurssikansiota paikkaan','Heading start'),
    'title_groupfolder': ('Kansion nimi','Label'),
# v1.87:
    'flea_asks': ('Opas:','Heading displayed in the scaffolding check list.'),
    'change_type': ('Vaihda tietmystyyppi?', 'Question at the end of the scaffolding check list.'),
    'no_change_possible': ('Tm on ainoa thn tilanteeseen sopiva tyyppi.','Text displayed when there is only one possible follow-up type and the type cannot be changed.'),
    'change': ('Vaihda', 'Button label'),
    'down_to_note': ('Hypp viestiin sikeess','Link label'),
    }

webtop = {
    'users_courses': ('Kurssit','Heading for users course list'),
    'new_notes': ('viesti','Label for displaying the number of new notes in a course'),
    'total_notes': ('yhteens','Label for displaying the total number of notes in a course'),
    'add_folder': ('Lis kansio',''),
    'add_document': ('Lis dokumentti',''),
    'add_link': ('Lis linkki',''),
    'create_document': ('Lis muistilappu',''),
    'sort': (' ','Common heading for sort links by_name and by_date'),
    'by_name': ('nimi','Link for sorting by name'),
    'by_date': ('pivys','Link for sorting by date'),
    'by_size': ('koko','Link for sorting by size'),
    'remove': ('Poista','Button label'),
    'restore': ('Palauta','Button label'),
    'rename': ('Nime','Button label'),
    'copy': ('Kopioi','Button label'),
    'cut': ('Leikkaa','Button label'),
    'paste': ('Liimaa','Button label'),
    'delete': ('Tuhoa','Button label'),
    'trash': ('Roskakori','Label for trashcan'),
    'adding_folder': ('Kansion lisminen','Heading'),
    'title_of_folder': ('Kansion nimi','Label'),
    'viewing_memo': ('Muistilapun katsominen','Title'),
    'adding_memo': ('Muistilapun lisminen','Title'),
    'editing_memo': ('Muistilapun muokkaminen','Title'),
    'name_of_memo': ('Muistilapun nimi','Label'),
    'content': ('Sislt','Label'),
    'show_memo_contents': ('Nyt vain muistilapun sislt','Link'),
    'adding_link': ('Linkin lisminen','Title'),
    'title_of_link': ('Linkin nimi','Label'),
    'url': ('URL',''),
    'document_uploaded': ('Dokumentti vastaanotettu.','Status message'),
    'adding_document': ('Dokumentin lisminen', 'Title'),
    'upload_document': ('Lhet dokumentti','Label'),
    'title_of_document': ('Dokumentin nimi','Label'),
# v1.9:
    'webtop_link_added': ('Linkki listty verkkopydlle','Message title'),
    'added_webtop_link': ('Linkki %s on luotu verkkopydllesi. Paina OK palataksesi edelliselle sivulle.','Message text; "to type" and "name" inserted into placeholders (2)'),
    'proxy_added': ('Kurssikansio listty','Message title'),
    'added_proxy': ('Kurssin %s kurssikansio on nyt nkyviss verkkopydllsi. Paina OK palataksesi edelliselle sivulle.','Message'),
    'no_item_selected': ('Et valinnut mitn!','Message dialog title'),
    'select_item_first': ('Kaikki toiminnot (paitsi Liimaa) tarvitsevat vhintn yhden valinnan verkkopydlt. ','Message dialog message'),
    'no_file_supplied': ('Tiedostoa ei lhetetty.','Message text'),
    'renaming': ('Uudelleennimeminen', 'Title'),
    'invalid_names': ('Seuraavat nimet ovat virheellisi', 'Message dialog messsage'),
    'same_names': ('Annoit useammalle objektille saman nimen.', 'Message dialog message'),
    'names_in_use': ('Seuraavat nimet ovat jo kytss:', 'Message dialog message'),
# v1.19:
    'information': ('Kyttjtiedot','Link'),
    'preferences': ('Asetukset','Link'),
    'editing_preferences': ('Muokataan asetuksia','Title'),
    'shared': ('Yhteinen kurssikansio', 'Printed after the name of the group folder'),
    }

coursemgmnt = {
    'course': ('kurssi', 'part of browser title'),
    'courses': ('Kurssit','Title'),
    'add_course': ('Lis kurssi','Link'),
    'edit_course': ('Muuda kurssi','Button label'),
    'edit_participants': ('Osallistujat','Button label'),
    'creating_course': ('Uuden kurssin luominen','Title'),
    'editing_course': ('Kurssin muokkaaminen','Title'),
    'course_name': ('Kurssin nimi','Label'),
    'organization': ('Organisaatio','Label'),
    'methods': ('Menetelmt','Label'),
    'starting_date': ('Aloituspiv','Label'),
    'ending_date': ('Lopetuspiv','Label'),
    'create_groupfolder': ('Luo uusi ryhmkansio','Link'),
    'adding_users_to_course': ('Uusien kyttjien lisminen kurssille','Title, name of course is displayed after this'),
    'if_participants_not_users': ('Jos osallistujat eivt viel ole IVA-kyttji','Message'),
    'new_participants_to_system': ('uusia osallistujia IVA-palvelimell','Part of a phrase'),
    'by_email': ('shkpostitse','Part of a phrase'),
    'manually': ('ksin','Part of a phrase'),
    'fle_users': ('Kyttjt','Heading'),
    'down': ('Alas','Button label'),
    'up': ('Yls','Button label'),
    'teachers': ('Opettajat','Heading'),
    'tutors': ('Tutorit','Heading'),
    'students': ('Opiskelijat','Heading'),
    'add_button': ('Lis ->','Button label'),
    'remove_button': ('<- Poista','Button label'),
# v1.9:
    'no_course_selected': ('Kurssia ei ole valittu!','Message dialog title'),
    'select_course_first': ('Valitse kurssi kurssiluettelosta.','Message dialog message'),
    'set_published': ('Tietmystyyppijoukko on julkaistu.','Message dialog title/text'),
    'users_updated': ('Kyttjt pivitetty','Message dialog title/message'),
    'select_some_users': ('Valitse joitain kyttji','Message dialog title/message'),
# v1.19:
    'edit_course_info': ('Muokkaa kurssin tietoja','Link'),
    'edit_course_participants': ('Muokkaa kurssin osallistujia','Link'),
    'date': ('Aikavli','Label, followed by the starting and ending date of the course.'),
    'course_participants': ('Kurssin osallistujat','Label'),
    'type_sets': ('Tietmystyyppijoukot','Label, plural'),
    'delete': ('Tuhoa','Button label'),
# v1.31:
    'new_typeset': ('Lis tietmystyyppijoukko','Link'),
    'tt_yellow': ('Keltainen','Knowledge type colour name'),
    'tt_yellowlt': ('Vaaleankeltainen','Knowledge type colour name'),
    'tt_orange': ('Oranssi','Knowledge type colour name'),
    'tt_orangelt': ('Vaaleanoranssi','Knowledge type colour name'),
    'tt_red': ('Punainen','Knowledge type colour name'),
    'tt_pink': ('Vaaleanpunainen','Knowledge type colour name'),
    'tt_purple': ('Violetti','Knowledge type colour name'),
    'tt_blue': ('Sininen','Knowledge type colour name'),
    'tt_bluelt': ('Valeansininen','Knowledge type colour name'),
    'tt_aqua': ('Aqua','Knowledge type colour name'),
    'tt_green': ('Vihre','Knowledge type colour name'),
    'tt_greenlt': ('Vaaleanvihre','Knowledge type colour name'),
    'tt_gray': ('Harmaa','Knowledge type colour name'),
    'tt_white': ('Valkoinen','Knowledge type colour name'),
    'edit_typeset': ('Muokataan tietmystyyppijoukkoa','Heading'),
    'create_typeset': ('Luodaan uutta tietmystyyppijoukkoa','Heading'),
    'form': ('Lomake','Start of heading'),
    'name': ('Nimi','Start of label'),
    'of_typeset': ('tietmystyyppijoukolle','Ending of label'),
    'abbreviations_and_icons': ('lyhenteet ja kuvakkeet','Ending for heading'),
    'type': ('Tietmystyyppi','Label'),
    'types': ('Tietmystyypit','Title'),
    'abbreviation': ('Lyhenne','Label'),
    'color': ('Vri','Label'),
    'icon': ('Kuvake','Label'),
    'starting_phrase': ('Aloituslause','Label'),
    'checklist': ('Tarkistuslista','Label'),
    'no_types_entered': ('Et syttnyt yhtn tietmystyyppi. Joukossa on oltava ainakin yksi tyyppi.',
  'Error message for when a new set is created with no types'),
    'restrictions_of_use': ('Kyttrajoitukset','Heading sentence.'),
    'that_can_start_thread': ('jolla voi aloittaa keskustelun','End of label'),
    'viewing_type': ('tietmystyypin katsominen','Part of location bar'),
    'new_typeset_from': ('Kopio ja editoi tietmystyyppijoukko','Link, followed by knowledge type set name'),
    'unfinished': ('Keskenerinen','Label'),
    'manage_types': ('Tietmystyyppijoukot','Link'),
    'finalize_typeset': ('Aseta tila valmistuneeksi','Button label'),
    'are_you_sure': ('Oletko varma ett haluat tuhota seuraavat kurssit:','Message dialog message'),
    'are_you_sure_ctx': ('Oletko varma ett haluat tuhota tmn kurssiosuuden:','Message dialog message'),
    'are_you_sure_tts': ('Oletko varma ett haluat tuhota seuraavat tietmystyyppijoukot:','Message dialog message'),
    'typeset_importing': ('Valitse zip-pakattu vientitiedosto, joka sislt tietmystyyppijoukot, jotka haluat tuoda jrjestelmn.','Instructions for typeset importing'),
    'typesets_imported': ('Uudet tietmystyyppijoukot on tuotu.','Message'),
    'import_typeset': ('Tuo tietmystyyppijoukko','link'),
    'course_importing': ('Valitse zip-pakattu vientitiedosto, joka sislt kurssit, jotka haluat tuoda jrjestelmn.','Instructions for course importing'),
    'courses_imported': ('Uudet kurssit on tuotu.','Message'),
    'import_course': ('Tuo kurssi','link'),
    
    'quota_reached_title': ('Tilaraja ylitetty','Title'),
    'quota_reached':  ('Toimintoa ei voitu suorittaa loppuun koska Verkkopytsi tilaraja on ylitetty. Poista joitakin dokumentteja Verkkopytltsi ja kokeile uudestaan.', 'Message dialog message'),

 # Sorting the users under user management #06.08 by Mart
  'sort_by': ('Jrjest kyttjt','Text before pull-down menu'),
  'limiters': ('Valintakriteerit:','Text before pull-down menu'),
  'modified': ('ajan','menu option'),
  'username': ('nimen mukaan','menu option'),
  'sort': ('Jrjest','button label'),
  'not_specified': (' ','default menu option'),
  'email': ('shkoposti','menu option'),
  'fname': ('etunimi','menu option'),  
  'since': ('lhtien','default value of textbox'),
  'until': ('saakka','default value of textbox'),  
    }

usermgmnt = {

    'user': ('kyttja','part of browser title'),
    'adding_users': ('Uusien kyttjien lisminen','Title'),
    'required_field': ('Pakollinen kentt',''),
    'nickname': ('Lempinimi','Label'),
    'user_account': ('Kyttjtunnus','Label'),
    'Confirm': ('Varmista',''),
    'you_are_removing': ('Olet poistamassa',''),
    'invite_user': ('Kutsu uusia',''),
    'invite_new_users': ('Kyttjien kutsuminen','Heading for invitation form'),
    'email_addresses': ('Skhpostiosoitteet',''),
    'separate_with_comma': ('(erottele pilkulla)',''),
    'Invitation_message': ('Kutsuviesti',''),
    'Invitation_language': ('Kutsukieli',''),
    'Courses_to_invite_to': ('Kutsuttavat liitetn kursseille',''),
    'Freeze': ('Lukitse',''),
    'Remove': ('Poista',''),

    'role': ('Rooli','label'),
    'role_staff': ('Henkilkunta','Global role staff'),
    'role_user': ('Kyttj','Global role user'),
    'role_fleadmin': ('IVA yllpitj','Global role ivaadmin'),

    'invite_again': ('Kutsu uudelleen','Button label'),
    'warning': ('Varoitus','Heading'),
    'want_remove_users': ('Haluatko poistaa seuraavat kyttjt?','Complete question'),
    'invited_user_manage': ('Kutsuttujen kyttjien hallinta','Title'),

    'info_user': ('Kyttjtiedot ','Title for user info page, prefix before usre name'),
    'edit_user': ('Muokkaa kyttjn tietoja','Link'),
    'name': ('Kyttjtunnus',''),
    'editing': ('Muokataan kyttj','Heading for user edit, inserted before user name'),
    'image_of_user': ('Kyttjn kuva','Label'),
    'upload_image_of_user': ('Lhet kyttjn kuva','Label'),
    'or_link_to_image': ('tai anna linkki kuvaan','Label, continuing from the upload label'),
    'add_new_user': ('Lis uusi','Title'),
    'webtop_bg': ('Valitse verkkopytn taustakuva','Label'),
    'upload_webtop_bg': ('tai lhet oma taustakuvasi','Label, continuing from the webtop_bg'),
    'show_pending_users': ('Nyt rekisteritymttmt',''),
    'add_user': ('Lis uusi',''),
    'Unfreeze': ('Vapauta',''),
    'Users': ('Kyttjt',''),
    'gsm': ('Knnykk',''),
    'last_name': ('Sukunimi',''),
    'first_name': ('Etunimi',''),
    'city': ('Kaupunki',''),
    'organization': ('Organisaatio',''),
    'professional_interests': ('Ammattimaiset kiinnostuksen kohteet',''),
    'email': ('Shkposti',''),
    'phone': ('Puhelin',''),
    'language': ('Kieli',''),
    'url_to_photo': ('Kuvan URLi',''),
    'country_menu_default': ('Valitse maa',''),
    'group_menu_default': ('Valitse ryhm','Default value for drop-down menu'),
    'address': ('Osoite',''),
    'address1': ('Osoiterivi 1',''),
    'address2': ('Osoiterivi 2',''),
    'personal_interests': ('Henkilkohtaiset kiinnostuksen kohteet',''),
    'quote': ('Mietelause',''),
    'homepage': ('Kotisivu',''),
    'upload': ('Lhet',''),
    'group': ('Ryhm',''),
    'password': ('Salasana',''),
    'background': ('Taustakuva',''),
    'country': ('Maa',''),
# v1.9:
    'reserved_nickname': ('Valitettavasti lempinimesi on jo varattu.','Message'),
    'password_mismatch': ('Annetut salasanat eivt vastaa toisiaan.','Message'),
    'could_not_send_invitation': ('Kutsuviestin lhetys eponnistui. Tarkista MailHost-sdt.','Error message'),
    'invitations_sent': ('Kutsut lhetetty','Message title'),
    'invitations_sent_to': ('Kutsut lhetetty seuraviin osoitteisiin: %s. ','Message, email list is inserted into the placeholder.'),
    'users_removed': ('Kyttjt poistettu','Message title'),
    'removed_users': ('Seuraavat kyttjt on poistettu:  %s','Message, list inserted inside'),
    'not_removed_users': ('Seuraavia kyttji ei voitu poistaa:  %s','Message, list inserted inside'),
    're_invitations_sent': ('Uudelleenkutsut lhetetty','Message title'),
    're_invitations_sent_to': ('Uudelleenkutsut lhetettiin %s kyttjlle. ','Message, email count is inserted into the placeholder.'),
    'pending_users_removed': ('Kutsutut kyttjt poistettu','Message title'),
    'pending_removed_users': ('Seuraavat kutsutut kyttjt on poistettu: %s','Message, list inserted inside'),
    'pending_not_removed_users': ('Seuraavien kutsuttujen kyttjien poistaminen eponnistui: %s','Message, list inserted inside'),
    'invitation_subject': ('Kutsu I.V.A. oppimisympristn','Subject for invitation messages'),
    'invitation_header': ('Kutsu','Header for invitation messages'),
    'invitation_footer': ('Avaa osoite: ','Footer for invitation messages; followed by the URL'),
# v1.15:
    'welcome_message': ('Tervetuloa I.V.A.-kyttjksi. Ole hyv ja anna seuraavat tietosi.','Welcome message used in invitation registration form'),
    'uname': ('Kyttjtunnus','Label used in invitation registration form'),
    'registration_failed': ('Rekisterityminen eponnistui','Title used when invited user cant register.'),
    'invitation_key_used': ('Tm kutsukoodi on jo kytetty tai ei en ole voimassa. Jos et ole pystynyt rekisteritymn, ota yhteytt opettajaasi saadaksesi uuden kutsun.','Message telling that the registration url has been used.'),
    'authorization_failed': ('Varmistusavaimet eivt kelpaa','Message telling that the authentication key isnt valid.'),
# v1.19:
    'after_submit_give_name_and_passwd': ('Lhetys-napin painamisen jlkeen anna kyttjtunnuksesi ja salasanasi.','Message'),
# v1.21:
    'frozen': ('Jdytetty','User status code'),
# v1.22:
    'no_email': ('Ei shkpostiosoitetta', 'Message title'),
    'no_email_explanation': ('Et voi lhett shkpostia, koska et ole asettanut omaa shkpostiosoitettasi.', 'Message text'),
    'passwd_changed': ('Salasana vaihtunut','Message title'),
    'passwd_changed_explanation': ('Olet vaihtanut salasanasi.','Message text'),
    }

jam = {
    'add_new_jam_session': ('Lis jammailusessio','link'),
    'jam_sessions': ('Jammailusessiot:', 'a list of jam session will listed after/under this label'),
    'jam_session': ('jammailusessio', ''),
    'annotations': ('selitett', ''),
    'continue_with_version': ('Luo versio', 'button label'),
    'artefact': ('tekele', ''),
    'viewing_annotations': ('selitteiden katselu', ''),
    'Annotations': ('Selitteet:', 'Label, followed by a list of annotations under it'),
    'add_annotation': ('Lis selite', 'link'),
    'adding_new_jam_session': ('Jammailusession lisminen', ''),
    'title_of_jam_session': ('Jammailusession otsikko', 'label'),
    'type_of_jam_session': ('Jammailusession rakenne', 'label'),
    'mutate_on_previous': ('Muunna edellist (jono)', 'type of jam session'),
    'explore_possibilities': ('Tutki vaihtoehtoja (puu)', 'type of jam session'),
    'diverge_and_converge': ('Eriyt ja yhdistele (verkko)', 'type of jam session'),
    'description_of_jam_session': ('Jammailusession kuvaus', 'label'),
    'upload_the_starting_artefact': ('Lhet aloitustekele', 'label'),
    'name_of_the_starting_artefact': ('Aloitustekeleen nimi', 'label'),
    'annotation_of_the_starting_artefact': ('Selite aloitustekeleelle', 'label'),
    'adding_new_artefact': ('Tekeleen lisminen', ''),
    'name_of_the_artefact': ('Tekeleen nimi', 'label'),
    'upload_file': ('Lhet tiedosto', 'label'),
    'you_adding_annotation': ('Olet lismss selitett tekeleeseen', 'message in adding annotations form'),
    'adding_annotation': ('Selitteen lisminen', ''),
    'to_jam_session': ('jammailusessioon', 'Part of a message'),
    'to_jam_artefact': ('jammailutekeleeseen', 'Part of a message'),
    'unread_artefacts': ('uutta tekelett', 'There is a number before this message'),
    'total_artefacts': ('tekelett yhteens', 'There is a number before this message'),
    'are_you_sure_jam_sessions': ('Oletko varma, ett haluat tuhota seuraavat jammailusessiot:' , 'Message dialog message'),
    'censor_artefact': ('Poista tekele', 'Button label for censoring jam artefact'),
    'uncensor_artefact': ('Palauta tekele', 'Button label for uncensoring jam artefact'),
    'censor_annotation': ('Poista valitut selitteet', 'Button label for censoring jam annotations'),
    'uncensor_annotation': ('Palauta valitut selitteet', 'Button label for uncensoring jam annotations'),
    'censored_name': ('Poistettu', 'Title/name for censored jam artefact'),
    'censored_message': ('Tmn tekeleen on poistanut %s (%s).', "First placeholder is replaced by censorer's name and the second by the date"),
    'censored_msg': ('Tekele on poistettu.', 'Message shown when teacher censores an artefact.'),
    'censored_annotation_msg': ('Selite on poistettu.', 'Message shown when teacher censores an annotation.'),
    'censor_verify': ('Haluatko varmasti poistaa tmn tekeleen? Nimesi ja tm pivys tallennetaan ja nytetn poistotiedon ohella kaikille, jotka katsovat tt tekelett.','Verification message shown when censoring is attempted'),
    'censor_annotations_verify': ('Haluatko varmasti poistaa tmn selitteen? Nimesi ja tm pivys tallennetaan ja nytetn poistotiedon ohella kaikille, jotka katsovat selitteit.','Verification message shown when censoring is attempted'),
    'censored_annotation_body': ('Tmn selitteen on poistanut %s (%s).',"Body for censored annotation. First placeholder is replaced by censorer's name and the second by the date"),
    }

ivacommon = {
  #editform.dtml - ZWiki
  'ic_zwiki_change':('Muokkaa','Button label - change Wiki page'),
  
  'ic_zwiki_modifiers':('Muokkaajat','leivapuru'), #05.08
  'ic_zwiki_who_modified':('Kuka on sit muokannut','Heading'), #05.08
  'ic_zwiki_nobody_modified':('Kukaan ei ole viel muokannut sit','Message'), #05.08
  
  #jooksva_kursuse_nimi.dtml
  'ic_no_course_selected':('Kurssia ei ole valittu',''),
  #kasutajakursused_valik.dtml
  'ic_select_course':('Valitse kurssi:',''),
  'ic_change_course':('OK',''),
  'ic_not_added_to_courses':('Kyttj ei ole rekisterity kurssille',''),

  #tootoad_kursusel.dtml #16.02
  'ic_knowledge_building_link':('Tiedonrakentelu',''),
  'ic_jamming_link':('Jammailu',''),
  'ic_wiki_link':('Wiki',''),
  'ic_no_course_selected':('Kurssia ei ole valittu',''),
  '':('',''),
  '':('',''),

  #Kirjakast.py #28.12
  'ic_nomail':('Uusia kirjeit ei ole','Message'),
  'ic_to':('Kenelle: ','Field name'),
  'ic_subject':('Otsikko: ','Field name'),
  'ic_text':('Sislt: ','Field name'),
  'ic_send':('Lhet','Button label'),
  'ic_newmail':('Uusi kirje','Left menu item'),
  'ic_mailbox':('Kirjelaatikko','Left menu item'),
  'ic_outbox':('Lhetetyt','Left menu item'),
  'ic_sender':('Lhettj','Table column heading'),
  'ic_title':('Otsikko','Table column heading'),
  'ic_sentdate':('Pivys','Table column heading'),
  'ic_select_whom':('Vastaanottaja(t):','Text before pull-down menu'), #06.01.2004
  'ic_add_name':('Lis',''), #06.01.2004

  'ia_task':('Tehtv','Title'),#07.01.2004
  'ia_deadline_updated':('Aikaraja pivitetty: ','Message'),#07.01.2004
  'ia_no_deadline':('Ei aikarajaa','Message'),#07.01.2004
  'ia_task_added':('Uusi tehtv listty','Message'),#07.01.2004

  #ui/Note/content.dtml #06.01.2004
  'ic_delete_note':('Poista viesti','Link label'),

  #Course.py #28.12
  'ic_removed':('Poistettu','Message'),
  'ic_registered':('Rekisterity','Message'),
  'ic_added_to_course':('Olet listty kurssille','Body of mail message'),
  'ia_none':('none','Message'),#07.01.2004
  '':('',''),

  #Webtop/index_html.dtml #16.02 - by Mart
  'ic_make_public':('Julkaise','Button label - Publish object from Drawer to Portfolio'),
  'ic_tocalendar':('Kalenteriin','Button label'), #08.10 Taavi
  'ic_eventmgt':('Kalenterin hallinta','Left menu item'), #08.10 Taavi

  'ic_pack':('Pakkaa','Button label'), #28.12
  'ic_loadzip':('Purkaa','Button label'), #28.12
  'ic_adding_zip':('Zip-tiedoston lhettminen ja purkaaminen','Page heading'),  #28.12
  'ic_unzipped':('Zip-tiedosto lhetetty ja purettu.','Message'), #28.12
  'ic_upload_zip':('Valitse zip-tiedosto','Message before Browse-box'), #28.12
  'ic_advanced':('Laajennettu haku','Link label'), #28.12
  'ic_search':('Hae','Link label'), #28.12

  #ui/Webtop/wt_search.dtml #28.12 - by Taavi
  'ic_searching':('Haku','Title'), #28.12
  'ic_search_title':('Nimi: ','Field name'), #28.12
  'ic_search_owner':('Omistaja: ','Field name'), #28.12
  'ic_search_keyword':('Hakusana: ','Field name'), #28.12
  'ic_cancel':('Peru','Button label'), #28.12

  #ui/Webtop/wt_search_results.dtml #28.12 - by Taavi
  'ic_newsearch':('Uusi haku','Link label'), #28.12
  'ic_search_results':('Haun tulokset','Title'), #28.12
  'ic_result_type':('Tppi:','Column heading'), #28.12
  'ic_result_title':('Nimi:','Column heading'), #28.12

  #kaustadkursusel.dtml #16.02 - by Mart
  'ic_no_folders':('Ei ole kansioita','Message - No folders in this course'),
  'ic_course_info':('Kurssin tiedot','Left menu item - Course info'),
      
  
  #tootubade_leht.dtml #16.02 - 14  
  'ic_workshops_1':('typajat','Breadcrumbs'),
  '':('',''),
  
  #test_opilane.dtml #16.02
  'ic_test_list':('Tentit','Menu header'),

  
  #haldusleht.dtml #16.02
  'ic_management_page':('hallinta','Breadcrumbs'),
  
  
  #opetaja_menyy.dtml
  'ic_user_management':('Osallistujat','Left menu item - User management'),
  'ic_inner_group_management':('Ryhmien hallinta','Left menu item -'),
  'ic_test_management':('Tenttien hallinta','Left menu item -'),
  'ic_course_management':('Kurssihallinta','Left menu item -'),
  'ic_eventmgt':('Kalenterin hallinta','Left menu item'), #08.10 Taavi
  'ic_addpending':('Lis rekisteritymttmt','Left menu item'), #08.10 Taavi

  'ic_taskmgt':('Tehtvien hallinta','Left menu item'), #28.12

  #sisegrupi_lisamise_leht.dtml
  'ic_problem_in_adding_inner_group':('Virhe - ryhm ei voitu luota','Message'),

  #sisegrupiloetelu.dtml #16.02
  'ic_inner_groups_list':('Ryhmt',''),


  #sisegrupihaldus.dtml
  'ic_inner_group_management_2':('ryhmien hallinta','Breadcrumbs'), #16.02
  'ic_adding_inner_group':('Lis uusi ryhm',''),
  'ic_deleting_inner_group':('Poista ryhm',''),
  'ic_managing_inner_group_users':('Ryhmn jsenet',''),
  'ic_list_subgroups':('Ryhmlistat','Link label'), #28.12
  
  #sisegrupi_lisamise_vorm.dtml  #16.02
  'ic_name_of_new_group':('Uuden ryhmn nimi',''),
  'ic_create_new_group':('Lis','Button label'),
  'ic_inner_group_management_3':('ryhmien hallinta','Breadcrumbs'),
  'ic_adding_inner_group_2':('Ryhmn lisminen','Title'),
  
  #sisegrupikustutusvorm.dtml #16.02
  'ic_inner_group_management_4':('ryhmien hallinta','Breadcrumbs'),
  'ic_inner_group_deleting':('poistaminen','Breadcrumbs'),
  'ic_remove_inner_group':('Poista','Button label'),
  
  #sisegrupi_osaliste_vorm #16.02
  'ic_inner_group_management_5':('ryhmien hallinta','Breadcrumbs'),
  'ic_inner_group_participants':('Ryhmn jsenet',''),
  'ic_inner_group_other_course_participants':('Muut kurssilla osallistujat',''),
  'ic_inner_group_participants_in_group':('Jsenet',''),
  'ic_inner_group_change_participants':('Muokkaa','Button label'),
  '':('',''),
  '':('',''),
  
  #UserManager.py #05.10 Taavi
  'ic_firstname':('Etunimi','Field name'),
  'ic_lastname':('Sukunimi','Field heading'),
  'ic_username':('Kyttjtunnus','Field heading'),
  'ic_try':('Kokeile','Link label'),
  'ic_register':('Rekisteri','Link label'),
  'ic_forward':('Eteenpin','Link label'),
  'ic_missingdata':('Puutteelliset tiedot','Error message'), 
  'ic_upload':('Lhet','Submission button label'),
  'ic_adding_affil':('Ryhmtunnuksen lisminen','Page title'), #07.12.2004
  'ic_import_affil':('Tuo ryhmtunnukset txt-tiedostona','Subheading'), #07.12.2004
  'ic_course_changed':('Kurssilla %s on muokattu: ','Part of e-mail message'), #07.12.2004
  'ic_e_subject':('IVAn kurssisisltja muokattu','Subject row for e-mail notification'), #07.12.2004
  'ic_email_1':('Viimeisen uloskirjaudumisen jalkeen on ','First part of e-mail message'), #07.12.2004
  'ic_email_2':('aikana IVA kursseja muokattu, nimenomaan ','Second part of e-mail message'), #07.12.2004


  #tootoad_kursusel.dtml #05.10 Taavi
  'ic_grportfolio':('Ryhmportfoliot','Left menu item'),

  #kasutajaotsing.dtml #05.10 Taavi
  'ic_finduser':('Etsi','Button label'),
  'ic_delete':('Poista','Button label'),
  'ic_perm':('Rajoita','Button label'),
  'ic_perm_on':('Rajoitukset','UserInfo'),
  'ic_perm_off':('Ei rajoituksia','UserInfo'),
  'ic_perm_unset':('Puuttuu','UserInfo'),
  'ic_usermgt':('kyttjhallinta','Breadcrumbs'),
  'ic_addusers':('Lis kyttjt','Link label'),
  'ic_addaffiliation':('Lisa ryhmtunnus','Link label'),
  'ic_savecsv':('Tallenna CSV-tideostona','Link label'),
  'ic_affiliation':('Ryhmtunnus','Link label'),
  'ic_select_all':('Valitse kaikki','Link label'), #07.01.2004
  
  #veebilauaviited.dtml #05.10 Taavi
  'ic_portfolio':('Portfolio','Left menu item'),
  'ic_drawer':('Pytlaatikko','Left menu item'),
  'ic_wiki':('Wiki','Menu item'),
  'ic_logpage':('Lokisivu','Menu item'),

  #paevikuleht.dmtl #05.10 Taavi
  'ic_apply':('Avoimmet kurssit','Menu item'),
  
  #oigustePiiramine.dmtl #22.10 Taavi
  'ic_restrictac':('Kiell ryhmtunnksen muokkaaminen','Checkbox label'),
  'ic_restrictpc':('Kiell salasanan vaihtaminen','Checkbox label'),
  'ic_enforcepc':('Pakotta vaihtamaan salasana','Checkbox label'),
  'ic_change':('Muokkaa','Link label'),

  #edit_user_form.dtml #22.10 Taavi
  'ic_browserprefs':('Kyt selaimen kieli-asetuksia: ','Link label'),
  'ic_sendtomail':('Lhet shkpostitse: ','Field name'), #28.12
  'ic_messages':('kirjeet','Checkbox label'), #28.12
  'ic_grades':('arvosanat','Checkbox label'), #28.12
  'ic_changesbookshelf':('muutokset Kirjahyllyll','Checkbox label'), #28.12
  'ic_changeskb':('muutokset Tiedonrakentelu-foorumeissa','Checkbox label'), #28.12
  'ic_changesjamming':('muutused Jammailu-pajassa','Checkbox label'), #28.12

  #CourseManager.py #05.10 Taavi
  'ic_error':('Ongelma:','Error message'),
  'ic_nocourse':('Ei ole avoimmia kursseja','Message'),
  'ic_added':('Listty: ','Listing header'),
  'ic_quote':('Slogan','Field heading'),
  'ic_logo':('Logo','Field heading'),
  'ic_status':('Status','Field heading'),
  'ic_preparation':('Keskenerinen','Pull-down menu item'),
  'ic_open':('Avoin','Pull-down menu item'),
  'ic_closed':('Rekisterinti loppunut','Pull-down menu item'),
  'ic_finished':('Pttynyt','Pull-down menu item'),

  #FLEu.py
  'ic_help':('Apu','Main screen'), #16.02
  #hdr.dtml
  'ic_hdr_drawer':('pytlaatikko','leivapuru osa'),  #16.02 see ja jrgmised 4
  'ic_hdr_portfolio':('portfolio',''),
  'ic_hdr_context':('kirjahylly',''),
  'ic_hdr_workshop':('typajat',''),
  'ic_hdr_management':('hallinta',''),
  'ic_hdr_inner_group_name':('ryhm',''),

  #kasutajateemataust.dtml #07.04 Jaagup
  'ic_t_webtop':('Verkkopyt: henkilkohtaiset tyvlineet','Picture alt text'),
  'ic_t_context':('Kirjahylly: opettajan ressurssit','Picture alt text'),
  'ic_t_workshop':('Typajat: ryhmtyvlineet','Picture alt text'),
  'ic_t_management':('Hallinto: kyttijen, kurssien, ryhmien, tenttien hallinto','Picture alt text'),
  'ic_t_':('','Picture alt text'),
  'ic_t_':('','Picture alt text'),  
  
  #ui/CourseManager/index_html.dtml #05.08
  'ic_add_users':('Kyttjhallinta','Link'),


  #ui/CourseManager/course_info_content.dtml #28.12
  'ic_imail':('Kirje kaikille osallistujille','Link label'),#28.12
  'ic_archive':('Arkivoi kurssi','Link label'),#28.12 

  #ui/Course/index_html.dtml #16.02
  'ic_kb_1':('Tiedonrakentelu','leivapuru'),
  'ic_export':('Vie kurssi','Link label'), #28.12
  'ic_changestatus':('Vaihda status','Button label'), #28.12

  #ui/Jamming/index_html.dtml #16.02
  'ic_jam_1':('Jammailu','leivapuru'),
  
  #standard_wiki_footer.dtml #16.02, muudetud 19.02 Mart
  'ic_change_wiki_page':('Muokkaa','link'), 
  'ic_add_wiki_comment':('Lis selite','Button'),
  'ic_wiki_export':('Vie','Link label'),#28.12
  '':('',''),

  #pildid  #kasutajateemataust.dtml hdr.dtml #29.03
  'ic_picture_webtop_1':('webtop1_fi','graphical menu button'),
  'ic_picture_webtop_2':('webtop2_fi','graphical menu button'),
  'ic_picture_bookshelf_1':('bookshelf1_fi','graphical menu button'),
  'ic_picture_bookshelf_2':('bookshelf2_fi','graphical menu button'),
  'ic_picture_management_1':('management1_fi','graphical menu button'),
  'ic_picture_management_2':('management2_fi','graphical menu button'),
  'ic_picture_workshops_1':('workshops1_fi','graphical menu button'),
  'ic_picture_workshops_2':('workshops2_fi','graphical menu button'),
  '':('',''),
  '':('',''),

  #Cruft.py
  'ic_user_not_found':('Kyttj ei lytynyt','message'), #29.03
  'ic_no_user_data_in_this_course':('ei tietoja kyttjst tll kurssilla','message'),
  'ic_no_events_for_user':('Kyttjn kalenteri on tyhj','message to the viewer of event'),

  'ic_info_user_name':('Kyttjtunnus','Table column heading'), #01.04
  'ic_info_number_open_pages':('Sivuja katsottu','Table column heading'),
  'ic_info_added_kb_notes':('Viestej listty','Table column heading'),
  'ic_info_read_kb_notes':('Viestej luettu','Table column heading'),
  'ic_info_added_jamming_artefacts':('Tekeleit listtu','Table column heading'),
  'ic_info_test_results':('Tenttitulokset','Table column heading'),
  'ic_info_last_access':('Viimeinen vierailu','Table column heading'),
  'ic_info_total_mark':('Arvosana','Table column heading'),
  'ic_info_comment':('Selite','Table column heading'),
  'ic_info_save':('Tallenna','Button label'),
  'ic_user_adding':('kyttjien lisminen','Leivapuru'), #05.08
  'ic_user_names':('Uusien kyttjien lataaminen tekstitiedostosta','Pealkiri'), #05.08
  'ic_user_create':('Luo','Button label'),#05.08
  
  '':('',''),

  #kylastajateLoetelu (WebtopFolder.py)  #05.04 Mart
  'ic_name':('Nimi','Table column heading'),
  'ic_date':('Pivys','Table column heading'),  
  'ic_nobody_read':('Kukaan ei ole viel katsonut sit','Message text'),
  'ic_viewed_by':('Kuka on sit katsonut?','Page heading'),
  'ic_viewers':('katsojat','Breadcrumbs'),
  
  'ic_mail_to_all':('Lhet shkposti koko luokalle', 'Link label'), #07.04 Jaagup
  'ic_course_statistics':('Tilastotiedot', 'Link label'),

  'ic_copy1':('kopio', 'part of label'), #04.12.03 Jaagup
  'ic_copy2':('kopio', 'part of label'), #04.12.03 Jaagup



  #UserInfo.py
  'ic_month_jan':('tammikuu', 'Calendar month'),  #15.09.03 Jaagup
  'ic_month_feb':('helmikuu', 'Calendar month'),
  'ic_month_mar':('maaliskuu', 'Calendar month'),
  'ic_month_apr':('huhtikuu', 'Calendar month'),
  'ic_month_may':('toukokuu', 'Calendar month'),
  'ic_month_jun':('keskuu', 'Calendar month'),
  'ic_month_jul':('heinkuu', 'Calendar month'),
  'ic_month_aug':('elokuu', 'Calendar month'),
  'ic_month_sep':('syyskuu', 'Calendar month'),
  'ic_month_oct':('lokakuu', 'Calendar month'),
  'ic_month_nov':('marraskuu', 'Calendar month'),
  'ic_month_dec':('joulukuu', 'Calendar month'),
  'ic_author':('Tekij', ''),
  'ic_time':('Pivys', ''),
  'ic_enter_correct':('Anna oikea ', ''),
  'ic_hide':('Piiloita', 'Button label'), #28.12
  'ic_hiddenevents':('Piiloitetut tapahtumat', 'Button label'), #28.12
}

ivatests = {
  #Prefix it - Iva Test
  #YlTest.py
  'it_qt_public':('Julkaistu','Test status'),
  'it_qt_closed':('Suljettu','Test status'),
  'it_qt_between':('Rajoitukset','Test status'),
  'it_qt_status':('Status','Test status button'),
  'it_save_title':('Tallenna asetukset','Save quiz title'),
  'it_description_of_permissions':('Likipsy-oikeudet','Description of permissions'),
  'it_all_permission':('Kaikille','All course participants can solve the test'),
  'it_inner_groups_permission':('Ryhmille','Inner groups which participants can solve test'),
  'it_user_permission':('Henkilkohtaiset','Users who have permission to solve test'),
  'it_add_user_permission':('Lis','Button to add user permission'),
  'it_add_group_permission':('Lis','Button to add group permission'),
  'it_question':('Kysymys','Question in page creating test'),
  'it_answer':('Vastaus',''),
  'it_type':('Tyyppi',''),
  'it_deletion':('Poista',''),
  'it_points':('Pisteet',''),
  'it_change':('Muokkaa','Change exercise in test'),
  'it_change_exercise':('Muokkaa','Change exercise in test, label after each exercise'), #16.02
  'it_delete_exercise':('Poista',''),
  'it_make_public':('Julkaise','Make quiz public to solve'),
  'it_hide':('Piiloita',''),
  'it_add_exercise':('Lis kysymys (tyyppi): ',''),
  'it_results_from_users':('Oppilaiden vastaukset','Show, who and how solved test'),
  'it_import_from_hotpotatoes':('Lhet HotPotatos tiedosto','Import as text file'),
  'it_export_to_web_ct':('Vie WebCT-hen','Export to WebCT as text'),
  'it_solving_test':('Tentin %s suorittaminen',''),
  'it_save_solved_test':('Tallenna',''),
  'it_answers_saved':('Vastauksesi on tallennettu','Test answers saved'),
  'it_answer_instance':('versio',''),
  'it_quiz_responses':('Vastaukset','List of users answers'),
  'it_hdr_tests':('tentit','breadcrumbs'),  #16.02
  'it_problem_in_finding_users':('kyttj ei lydetty',''),
  'it_delete_permission':('Poista',''),
  'it_an_question':('Kysymys','Question in user answer list page'),
  'it_an_user_answer':('Vastattiin',''),
  'it_an_answer_commenting_table':('Kommentit',''),  #16.02
  'it_an_teacher_answer':('Opettajan vastaus','Teachers right answer'),
  'it_an_result':('Tulos','Is answer right'),
  'it_an_points':('Pisteit',''),
  'it_an_comment':('Kommentti',''),
  'it_anc_question':('Kysymys','Question in commenting answers page'),
  'it_anc_user_answer':('Oppilaan vastaus',''),
  'it_anc_teacher_answer':('Opettajan vastaus','Teacher suggested result'),
  'it_anc_result':('Tulos','Is answer right'),
  'it_anc_automatic_points':('Pisteit',''),
  'it_anc_teacher_points':('Lispisteit',''),
  'it_anc_nominal_points':('norm', ''),
  'it_anc_teachers_comment':('Opettajan kommentit',''),
  'it_anc_point_reading':('Pistelaskenta','Do teacher use this exercise points in test result summary'),
  'it_anc_comment_to_whole_answer':('Yleiskommentti','Teacher comment to all test answer'),
  'it_anc_save':('Tallenna','Save points and comments'),
  'it_no_percent_calculating':('prosentteja ei laskettu','No percent calculating, because no nominal points in this test.'),
  'it_test_answers':('Tentin %s vastaukset',''),
  'it_tests':('tentit',''),
  'it_answers':('vastaukset',''),

  'it_open_test':('Julkaise','Viide avamaks testi kigile titmiseks'), #29.03
  'it_opened_for_all':('Kaikille avoin','message in the list of quizzes'), #29.03
  'it_add_group_permission':('lis','link label - give quiz solving permission to a group'), #29.03
  'it_add_personal_permission':('lis','link label - give quiz solving permission to a person'), #29.03
  'it_delete_permission':('poista','Button label'),
  'it_no_users_without_permission':('Kaikilla oppilailla on oikeudet','message'), #29.03
  'it_no_groups_without_permission':('Kaikilla ryhmill on oikeudet','message'), #29.03

  'it_click_to_save':('Jos haluat lhett vastauksesi, palaa edelliselle sivulle selaimen Back-painikkeella ja klikkaa <Lhet>','Message text'), #28.12
  'it_type_quiz':('Tentti','Type of the test, pull-down menu item'), #28.12
  'it_type_selftest':('Harjoitus','Type of the test, pull-down menu item'), #28.12
  'it_type_survey':('Kyselylomake','Type of the test, pull-down menu item'), #28.12
  'it_quiz_title':('Otsikko','Field name'), #28.12
  'it_quiz_descr':('Kuvaus','Field name'), #28.12
  'it_quiz_type':('Tyyppi','Field name'), #28.12

  'it_warning_quiz':('Huomio! Jatka jos haluat NYT suorittaa tentin. <br>Ensimmisen suorituksen aloitusaika tallennetaan. ','Warning message - you are about to begin the quiz'),  #28.12 
  'it_quiz_started':('Tentin ensimminen suorittaminen alkoi: ','First part of a message'),  #28.12
  'it_begin_quiz':('Aloita nyt','Button label'),  #28.12
  'it_quiz_stats':('Tilastotiedot','Link label'),  #28.12
  'it_selftest_submit':('Tallenna vastaus','Button label'),  #28.12
  'it_selftest_end':('Harjoitus loppui','Message'),  #28.12
  'it_selftest_next':('Jatka','Button label'), #28.12
  'it_stat_choice':('Vastaus','Field label'), #28.12
  'it_stat_count':('Tarjottu','Field label'), #28.12
  'it_stat_hits':('Oikeita','Field label'), #28.12
  'it_stat_err':('Vialliset vastaukset','Field label'), #28.12
  'it_editing_quiz':('Tentin muokkaaminen','Page heading'), #28.12
  'it_totalpoints':('Pisteit yhteens: ','Part of message'), #28.12
  'it_grading':('Arvosana','Link label'), #28.12
  'it_ca_onclosing':('vasta sulkemisen jlkeen','Pull-down menu item'), #28.12
  'it_ca_always':('aina','Pull-down menu item'), #28.12
  'it_ca_never':('ei koskaan','Pull-down menu item'), #28.12
  'it_ca_visible':('Oikeita vastauksia nytetn oppilaille: ','Message before pull-down menu'), #28.12
  'it_editing_settings':('Tentin asetuksien muuttaminen','Page heading'), #28.12
  'it_submissions':('Suorituksia: ','Field label'), #28.12
  'it_no_stats':('Ei tilastotietoja','Message'), #28.12
  'it_stat_scored':('Pisteit sai ','Part of a message'), #28.12
  'it_stat_total':(' oppilasta, yhteens kertiin pisteit: ','Part of a message'), #28.12
  'it_stat_notempty':('Vastauksia: ','Part of a message'), #28.12

  'it_restrictions':('Rajoitukset','Link label'), #07.01.2004
  'it_notpublic':('Julkaisematon','Button label'),#07.01.2004
  'it_for_all':('Avoin kaikille','Button label'),#07.01.2004
  'it_for_subgroups':('Avoin ryhmittin','Button label'),#07.01.2004
  'it_for_persons':('Avoin henkilittin','Button label'),#07.01.2004
  'it_you_answered':('Vastauksesi oli: ','Message'),#07.01.2004
  'it_feedback':('Palaute ','Page heading'),#07.01.2004
  'it_right_answer':('Oikea vastaus: ','Message'),#07.01.2004
  'it_excercise':('Harjoitus','Page heading'),#07.01.2004
  '':('',''), #28.12
  '':('',''), #28.12
  '':('',''), #28.12
  '':('',''), #28.12
  '':('',''), #28.12
  '':('',''), #28.12

 #kasutajateTulemused - testitulemuste kuvamise leht
  'it_show_comments':('Nyt kommentteja','Link label'), #05.04 Mart
  'it_hide_comments':('Piiloita kommentit','Link label'), #05.04 Mart

 #lubadeViited 
  'it_timelimit':('aikaraja','Link label'), #05.04 Mart 

 #koigiLuba - testi piirangute seadmise vorm
  'it_start_time':('Aloitusaika','Table column heading'), #05.04 Mart
  'it_end_time':('Lopetusaika','Table column heading'), #05.04 Mart
  'it_repeat':('Kertaukset','Table column heading'), #05.04 Mart
  'it_unlimited':('Rajoituksitta','Table column heading'), #05.04 Mart
  'it_save':('Tallenna','Button label'),  #05.04 Mart

  
  '':('',''),
  '':('',''),

  #testihaldus.dtml #19.02 - by Mart
  'it_add_test':('Lis tentti','Menu item - Add quiz'),
  'it_tests_bread':('tentit','Breadcrumb'),
  'it_test_select':('Valitse','Table column heading'), #29.03
  'it_test_id':('ID','Table column heading'), #29.03
  'it_test_name':('Nimi','Table column heading'), #29.03
  'it_test_ready_to_solve':('Julkaistu','Table column heading'), #29.03
  'it_test_rename':('Asetukset','Button label'),
  'it_test_delete':('Poista','Button label'),
  'it_test_export':('Vie','Button label'),
  'it_test_import':('Tuo','Button label'),

  'it_test_randomized':('Satunnaisjrjestys','Table column heading'), #05.04
  'it_test_submissions':('Suoritukset','Table column heading'), #05.04
  'it_test_randomize':('Satunnaistaa','Button label'), #05.04

  'it_test_type':('Tyyppi','Table heading'), #28.12

  '':('',''),
    
  
  #YlAlus.py
  'it_incorrect_point_count':('Virheellinen pistelaskenta','Error message'), 
  'it_ex_question':('Kysymys','Link label'), 
  'it_ex_save':('Tallenna','Button label'),
  '':('',''),
  #'it_no_point_calculating':('pisteit ei lasketa','message'), 
  'it_link_url':('URL','Form item label'), 
  'it_link_text':('Linkin nimi','Form item label'), 
  'it_delete_picture':('Poista','Form checkbox label'), 
  'it_no_automatic_point_calculating':('Pisteit ei lasketa','message'), 
  'it_nominal_points':('Max pisteet','message'), 
  'it_no_link_address':('Osoite puuttuu','Error message'), 
  'it_incorrect_URL':('Viallinen URL','Error message'), 

  'it_describing_text':('Kuvaus', 'Form item label'), #29.03

  'it_picture':('Kuva','Form item label'), #05.04 Mart
  
  #YlTyybid.py 
 # 'it_incorrect_answer':('Vra vastaus','message'),
  'it_no_saved_answer':('Vastausta ei tallennettu','message'),
  'it_no_answer_text':('Vastaus puuttuu','message'),
  'it_no_choices':('Valinnat puuttuu','message'),
  'it_no_answer':('Vastaus puudub','message'),
  'it_no_choices_in_viewing':('Valinnat puuttuu','message'),
  'it_problem_with_data':('Virhe','message'),
  'it_correct_answers':('Oikeat vastaukset','message'),
  
  
  #The types of quiz items in the pull-down menu #29.03
  'it_check_exercise':('Kyll/ei','The type of quiz item in pull-down menu'), 
  'it_text_answer_exercise':('Vapaa teksti','The type of quiz item in pull-down menu'),  
  'it_one_answer':('Lyhyt vastaus','The type of quiz item in pull-down menu'), #29.03  
  'it_multiple_choice_exercise':('Monta oikeata','The type of quiz item in pull-down menu'),
  'it_one_answer_exercise':('Yksi oikea','The type of quiz item in pull-down menu'), 
  'it_number_space_exercise':('Numerovastaus +/-','The type of quiz item in pull-down menu'), 
  'it_percent_excercise':('Prosenttilaskenta','The type of quiz item in pull-down menu'), 
  'it_matching_exercise':('Lyt parit','The type of quiz item in pull-down menu'), 
  '':('',''),
  
  #iged variandid #05.08
  'it_ov_variant':('Versio','Table heading'),
  'it_ov_explanation':('Selite','Table heading'),
  'it_ov_correct':('Oikea','Table heading'),
  

  
  #Yksikvalik #05.08
  'it_yv_variants':('Versio','Table heading'),
  'it_yv_correct':('Oikea','Table heading'),
  'it_yv_explanation':('Selite','Table heading'),
  '':('',''),


  #Numerical item settings, #29.03
  'it_av_min_correct':('Alaraja','Table heading'),  
  'it_av_centre_correct':('Oikea','Table heading'), 
  'it_av_max_correct':('Ylraja','Table heading'), 
  'it_av_checking_type':('Pistelaskenta','Question before menu options'), 
  'it_av_space':('Tasainen','Menu option. Maximum score if answer falls anywhere within the range'),
  'it_av_linear':('Supistuva','Menu option. Score given depends on distance from exact answer.'),

  #Percent calculation item settings, #29.03
  'it_pr_solvents':('vett; destilleeritud vesi','List of default solvents, separated with semicolon'), 
  'it_pr_soluble':('suola; sokeri','List of default solubles, separated with semicolon'),
  'it_pr_term_solution_percent':('Liuoksen vahvuus prosenteissa','Text, used in several contexts: Percentage of solution'),
  'it_pr_term_solvent_amount':('Liuotiimen mr','Text, used in several contexts: amount of solvent'),
  'it_pr_term_soluble_amount':('Aineen mr','Text, used in several contexts: amount of soluble'),
  'it_pr_term_soluble_to_solvent':('Aine/liuottin','Text, used in several contexts'),
  'it_pr_term_asking_answer':('Etsittv','Comment to solver'),
  'it_pr_soluble_amount_space':('Aineen mrn yl- ja alaraja','Label on the page of entering the question: range'),
  'it_pr_solvent_amount_space':('Liuottimen mrn yl- ja alaraja, mittayksikk','Label on the page of entering the question: range'),
  'it_pr_soluble_names':('Aineiden nimet, mittayksikkt','Label on the page of entering the question: names and units'),
  'it_pr_solvent_names':('Liuottimien nimet, mittyksikkt, hik','Label on the page of entering the question: names and units'),
  'it_pr_answer_exactitude_percent':('Vastauksen tarkkuus (prosenttia)','Label on the page of entering the question'),
  'it_pr_answer_type':('Vastauksen tyyppi','Label on the page of entering the question: searchable'),
  'it_pr_checking_type':('Laskenta','Question before menu options'),
  'it_pr_space':('Tasainen','Menu option: Maximum score if answer falls anywhere within the range'),
  'it_pr_linear':('Supistuva','Menu option: Score given depends on distance from exact answer'),

  #Vastavuspaarid #05.08
  'it_mt_left':('Vasemalla','Table heading'),
  'it_mt_right':('Oikealla','Table heading'),

  #YlVahendus.py 
  'it_send_text':('Lhet','Button label'),
  'it_send_file':('Lhet','Button label'),
  'it_choosing_exercise_type':('Kysymyksen tyypin valinta','Page title'),

  'it_check_exercise_default_question':('Kysymyksen teksti thn','Default question heading'),     #16.02 jj
  'it_text_answer_exercise_default_question':('Kysymyksen teksti thn','Default question heading'),
  'it_one_answer_default_question':('Kysymyksen teksti thn','Default question heading'),
  'it_multiple_choice_exercise_default_question':('Kysymyksen teksti thn','Default question heading'),
  'it_one_answer_exercise_default_question':('Kysymyksen teksti thn','Default question heading'),

  'it_percent_exercise_default_question':('Lyt puuttuva tekij','Default question heading'), #29.03
  'it_matching_exercise_default_question':('Yhdist yhteensopivat parit','Default question heading'),
  'it_number_space_exercise_default_question':('Kysymyksen teksti thn','Default question heading'),
  '':('',''),
  '':('',''),
}

#New module added #07.09 by Taavi

ivaevents = {
  'ie_incomplete':('Keskenerinen','Pull-down menu item, incomplete event'),
  'ie_delete':('Poista','Submit button label, delete selected events'),
  'ie_complete':('Pttynyt','Pull-down menu item, complete event'),
  'ie_own':('Henkilkohtainen','Property of an event, inside of table listing'),
  'ie_name':('Nimi','Field name - Name of event'),
  'ie_teaser':('Lyhyt kuvaus','Field name - Short description of event'),
  'ie_body':('Pitk kuvaus','Field name - Full description of event'),
  'ie_starttime':('Aloitusaika','Field name - Starting time of event'),
  'ie_endtime':('Lopetusaika','Field name - Ending time of event'),
  'ie_link':('Linkki','Field name - Link label'),
  'ie_attached':('Liitetiedosto','Field name - Attachment'),
  'ie_status':('Status','Field name - Status'),
  'ie_change':('Muokkaa','Link label - Change event'),
  'ie_save':('Tallenna','Button label - Save event description'),
  'ie_addevent':('Lis tapahtuma','Link label'),
  '':('',''),
  '':('',''),
}

#New module added #28.12 by Mart

ivatasks = {

#Kodutoo.py 
  'ia_addtask':('Lis tehtv','Link label'),
  'ia_grading':('Arvioi tehtvt','Link label'),
  'ia_title':('Otsikko','Table column heading'),
  'ia_type':('Tyyppi','Table column heading, also field label'),
  'ia_points':('Pisteit','Table column heading'),
  'ia_total':('Pisteit yhteens:','Field label'),
  'ia_delete':('Poista','Button label'),
  'ia_grade_labels':('Arvosana','Table column heading'),
  'ia_grade_percent':('Alaraja %','Table column heading'),
  'ia_submit':('Tallenna','Button label'),
  'ia_add':('Lis','Button label'),
  'ia_quiz':('Tentti','Pull-down menu item'),
  'ia_product':('Tuote','Pull-down menu item'),
  'ia_grpwork':('Ryhmty','Pull-down menu item'),
  'ia_presentn':('Esitys','Pull-down menu item'),
  'ia_select_quiz':('Valitse tentti','Default option in pull-down menu'),
  'ia_descr':('Kuvaus','Field label'),
  'ia_deadline':('Aikaraja','Field label'),
  'ia_edit':('Muokkaa','Button label'),
  'ia_editing_task':('Tehtvn asetuksien muuttaminen','Page heading'),
  'ia_adding_task':('Tehtvn lisminen','Page heading'),
  'ia_groups':('Ryhmt: ','Field label'),
  'ia_result':('Tulos','Table column header'),
  'ia_noscale':('Asteikko puuttuu','Error message - grading scale is missing'),
  'ia_nogrades':('Arvosanat puuttuu','Error message - grades are missing'),
  'ia_failed':('Ei hyvksytty','Error message - grade below satisfactory'),
  '':('',''),

#Course.py
  'ia_total_grade':('Arvosana','Table column heading'),
  'ia_no_folder':('Tehtvkansio puuttuu','Error message within the table'),
  'ia_gradetable':('Arvosanat','Page heading'),
  'ia_comment':('Kommentti','Table column heading'),
  'ia_scale':('Skaala','Table column heading'),
  'ia_view':('Katso','Link label'),
  'ia_maxpoints':('Norm: ','Field label'),
  'ia_none':('puuttuu','Message'),#07.01.2004
  'ia_savecsv':('Tallenna CSV-tiedostona','Link label'), #07.01.2004
  'ia_email_grades':('Lhet arvosanat e-postitse','Checkbox label'), #07.01.2004
  'ia_grademail_subject':('Arvosana IVA-kurssilla annettu','Subject of e-mail message with grade'), #07.01.2004
  'ia_grademail_body1':('Lopullinen arvosanasi IVA-kurssilla ','Part of e-mail message with grade'), #07.01.2004
  'ia_grademail_body2':('on: ','Part of e-mail message with grade'), #07.01.2004
  '':('',''),
  '':('',''),
  '':('',''),

#WebtopFolder.py  #07.01.2004
  'ia_edit_deadline':('Tm kansio suljettaan: ','Part of a message - Allowed to edit until:'),


#UserInfo.py #07.01.2004
  'ia_tasks':('Tehtvt','Folder name'),

}



# All vocabularies combined
vocabulary = {'common': common,
              'kb': kb,
              'webtop': webtop,
              'usermgmnt': usermgmnt,
              'coursemgmnt': coursemgmnt,
              'jam': jam,
              'ivacommon': ivacommon,
              'ivatests': ivatests,
              'ivaevents': ivaevents, #07.09
		  'ivatasks': ivatasks, #28.12
              }
              
#print vocabulary['ivacommon']['ic_change_wiki_page']

#EOF
